# -*- Mode: rpm-spec -*-
#
# Mandriva kernels now use kernel.org versioning
#
%define kernelversion	2
%define patchlevel	6
%define sublevel	22

# kernel Makefile extraversion is substituted by 
# kpatch/kstable wich are either 0 (empty), rc (kpatch) or stable release (kstable)
%define kpatch		0
%define kstable		9

# this is the real releaseversion
%define mdvrel		1

# this is used when building update candidates
#define uclevel uc1
%define devel_notice %{?uclevel:NOTE: This is work-in-progress (WIP) development kernel.}

# kernel base name (also name of srpm)
%define kname 		kernel

# Patch tarball tag
%define ktag		mdv

%define rpmtag		%distsuffix
%if %kpatch
%define rpmrel		%mkrel 0.%{kpatch}.%{mdvrel}%{?uclevel:.%{uclevel}}
%else
%define rpmrel		%mkrel %{mdvrel}%{?uclevel:.%{uclevel}}
%endif

# theese two never change, they are used to fool rpm/urpmi/smart
%define fakever		1
%define fakerel		%mkrel 1

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %kpatch
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%define tar_ver	  	%{kernelversion}.%{patchlevel}.%(expr %{sublevel} - 1)
%define patch_ver 	%{kversion}-%{kpatch}-%{ktag}%{mdvrel}
%else
%if %kstable
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}.%{kstable}
%define tar_ver   	%{kernelversion}.%{patchlevel}.%{sublevel}
%else
%define kversion  	%{kernelversion}.%{patchlevel}.%{sublevel}
%define tar_ver   	%{kversion}
%endif
%define patch_ver 	%{kversion}-%{ktag}%{mdvrel}
%endif
%define kverrel   	%{kversion}-%{rpmrel}

# used for not making too long names for rpms or search paths 
%if %kpatch
%define buildrpmrel     0.%{kpatch}.%{mdvrel}%{?uclevel:.%{uclevel}}%{rpmtag}
%else
%define buildrpmrel     %{mdvrel}%{?uclevel:.%{uclevel}}%{rpmtag}
%endif
%define buildrel     	%{kversion}-%{buildrpmrel}

# having different top level names for packges means that you have to remove them by hard :(
%define top_dir_name 	%{kname}-%{_arch}

%define build_dir 	${RPM_BUILD_DIR}/%{top_dir_name}
%define src_dir 	%{build_dir}/linux-%{tar_ver}

# disable useless debug rpms...
%define _enable_debug_packages 	%{nil}
%define debug_package 		%{nil}

# Build defines
%define build_doc 		1
%define build_source 		1
%define build_devel 		1
%define build_debug 		0

# Build desktop i586 / 1GB
%ifarch %{ix86}
%define build_desktop586	1
%endif

# Build desktop (i686 / 4GB) / x86_64 / sparc64 sets
%define build_desktop		1

# Build laptop (i686 / 4GB)/ x86_64
%ifarch %{ix86} x86_64
%define build_laptop		1
%endif

# Build server (i686 / 64GB)/x86_64 / sparc64 sets
%define build_server		1

# End of user definitions
%{?_without_desktop586: %global build_desktop586 0}
%{?_without_desktop: %global build_desktop 0}
%{?_without_laptop: %global build_laptop 0}
%{?_without_server: %global build_server 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}
%{?_without_devel: %global build_devel 0}
%{?_without_debug: %global build_debug 0}

%{?_with_desktop586: %global build_desktop586 1}
%{?_with_desktop: %global build_desktop 1}
%{?_with_laptop: %global build_laptop 1}
%{?_with_server: %global build_server 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}
%{?_with_devel: %global build_devel 1}
%{?_with_debug: %global build_debug 1}

# For the .nosrc.rpm
%define build_nosrc 	0
%{?_with_nosrc: %global build_nosrc 1}

%if %(if [ -z "$CC" ] ; then echo 0; else echo 1; fi)
%define kmake %make CC="$CC"
%else
%define kmake %make
%endif
# there are places where parallel make don't work
%define smake make

# Sparc arch wants sparc64 kernels
%define target_arch    %(echo %{_arch} | sed -e "s/sparc/sparc64/")


#
# SRC RPM description
#
Summary: 	Linux kernel built for Mandriva
Name:		%{kname}
Version: 	%{kversion}
Release: 	%{rpmrel}
License: 	GPL
Group: 	 	System/Kernel and hardware
ExclusiveArch: %{ix86} ppc powerpc x86_64 amd64 sparc sparc64
ExclusiveOS: 	Linux
URL: 		http://www.kernel.org/

####################################################################
#
# Sources
#
### This is for full SRC RPM
Source0: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.bz2
Source1: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/linux-%{tar_ver}.tar.bz2.sign
### This is for stripped SRC RPM
%if %build_nosrc
NoSource: 0
%endif

Source4: 	README.kernel-sources
Source5: 	README.MandrivaLinux

Source100: 	linux-%{patch_ver}.tar.bz2

####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/testing

%if %kpatch
Patch1:		ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}.%{sublevel}-%{kpatch}.bz2
Source10: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/testing/patch-%{kernelversion}.%{patchlevel}.%{sublevel}-%{kpatch}.bz2.sign
%endif
%if %kstable
Patch1:   	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kversion}.bz2
Source10: 	ftp://ftp.kernel.org/pub/linux/kernel/v%{kernelversion}.%{patchlevel}/patch-%{kversion}.bz2.sign
%endif

#END
####################################################################

# Defines for the things that are needed for all the kernels
#
%define common_description_kernel The kernel package contains the Linux kernel (vmlinuz), the core of your \
Mandriva Linux operating system.  The kernel handles the basic functions \
of the operating system:  memory allocation, process allocation, device \
input and output, etc.

%define common_description_info For instructions for update, see:	\
http://www.mandriva.com/security/kernelupdate				\
									\
%{devel_notice}

### Global Requires/Provides
%define requires1 	bootloader-utils >= 1.13-%mkrel 1
%define requires2 	mkinitrd >= 4.2.17-%mkrel 31
%define requires3	module-init-tools >= 3.0-%mkrel 7
%define requires4 	sysfsutils >= 1.3.0-%mkrel 1 

%define kprovides 	%{kname} = %{kverrel}, kernel = %{tar_ver}, alsa = 1.0.14, drbd-api = 86

%define kconflicts	drakxtools-backend < 10.4.190-%mkrel 2

BuildRoot: 		%{_tmppath}/%{kname}-%{kversion}-%{_arch}-build
Autoreqprov: 		no
BuildRequires: 		gcc >= 3.2-%mkrel 1 module-init-tools >= 3.0-%mkrel 7

%description
%common_description_kernel

%common_description_info

# this is a virtual kernel rpm to help the installer during the
# naming transition, can probably be removed post 2008.0 release
%package -n %{kname}-%{buildrel}
Version:	%{fakever}
Release:	%{fakerel}
Summary:	Virtual rpm for installing the default %{kname}
Group:		System/Kernel and hardware
Requires:	%{kname}-desktop-%{buildrel}
%description -n %{kname}-%{buildrel}
This package is a virtual rpm that helps the installer to install
the default %{kname} during the transition to the new naming scheme.

%common_description_info

%files -n %{kname}-%{buildrel}
%defattr(-,root,root)

# define obsolete/provides to help automatic upgrades of old kernel
# flavours to the new ones. Can probably be removed when 2007.1 gets EOL.
%define latest_obsoletes_desktop kernel-latest <= 2.6.22-%mkrel 6
%define latest_provides_desktop kernel-latest = %{kverrel}
%ifarch %{ix86}
%define latest_obsoletes_desktop586 kernel-legacy-latest <= 2.6.22-%mkrel 6
%define latest_provides_desktop586 kernel-legacy-latest = %{kverrel}
%define latest_obsoletes_server kernel-enterprise-latest <= 2.6.22-%mkrel 6
%define latest_provides_server kernel-enterprise-latest = %{kverrel}
%endif
# make kernel-desktop-devel-latest oboslete kernel-source-stripped-latest
# it's not a perfect match, but it's better than full source, and it does work
%define latest_obsoletes_stripped_desktop kernel-source-stripped-latest <= 2.6.22-%mkrel 6
%define latest_provides_stripped_desktop kernel-source-stripped-latest = %{kverrel}

# mkflavour() name flavour processor
# name: the flavour name in the package name
# flavour: first parameter of CreateKernel()
%define mkflavour()					\
%package -n %{kname}-%{1}-%{buildrel}			\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Provides:	%kprovides				\
Requires(pre):	%requires1 %requires2 %requires3 %requires4 \
Conflicts:	%kconflicts				\
Summary:	%{expand:%{summary_%(echo %{1})}}	\
Group:		System/Kernel and hardware		\
%description -n %{kname}-%{1}-%{buildrel}		\
%common_description_kernel %{expand:%{info_%(echo %{1})}} \
							\
%common_description_info				\
							\
%package -n	%{kname}-%{1}-devel-%{buildrel}		\
Version:	%{fakever}				\
Release:	%{fakerel}				\
Requires:	glibc-devel ncurses-devel make gcc perl	\
Summary:	The kernel-devel files for %{kname}-%{1}-%{buildrel} \
Group:		Development/Kernel			\
Provides:	kernel-devel = %{kverrel} 		\
%description -n %{kname}-%{1}-devel-%{buildrel}		\
This package contains the kernel-devel files that should be enough to build \
3rdparty drivers against for use with %{kname}-%{1}-%{buildrel}. \
							\
If you want to build your own kernel, you need to install the full \
%{kname}-source-%{buildrel} rpm.			\
							\
%common_description_info				\
							\
%package -n %{kname}-%{1}-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}	\
Group:		System/Kernel and hardware		\
Requires:	%{kname}-%{1}-%{buildrel}		\
%{expand:%%{?latest_obsoletes_%{1}:Obsoletes: %{latest_obsoletes_%{1}}}} \
%{expand:%%{?latest_provides_%{1}:Provides: %{latest_provides_%{1}}}} \
%description -n %{kname}-%{1}-latest			\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1} installed...			\
							\
%common_description_info				\
							\
%package -n %{kname}-%{1}-devel-latest			\
Version:	%{kversion}				\
Release:	%{rpmrel}				\
Summary:	Virtual rpm for latest %{kname}-%{1}-devel \
Group:		Development/Kernel			\
Requires:	%{kname}-%{1}-devel-%{buildrel}		\
%{expand:%%{?latest_obsoletes_stripped_%{1}:Obsoletes: %{latest_obsoletes_stripped_%{1}}}} \
%{expand:%%{?latest_provides_stripped_%{1}:Provides: %{latest_provides_stripped_%{1}}}} \
%description -n %{kname}-%{1}-devel-latest		\
This package is a virtual rpm that aims to make sure you always have the \
latest %{kname}-%{1}-devel installed...			\
							\
%common_description_info				\
							\
%post -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-post \
%preun -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-preun \
%postun -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1}-postun \
							\
%post -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-post \
%preun -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1}-preun \
							\
%files -n %{kname}-%{1}-%{buildrel} -f kernel_files.%{1} \
%files -n %{kname}-%{1}-latest				\
%defattr(-,root,root)					\
							\
%if %build_devel					\
%files -n %{kname}-%{1}-devel-%{buildrel} -f kernel_devel_files.%{1} \
%files -n %{kname}-%{1}-devel-latest			\
%defattr(-,root,root)					\
%endif


%ifarch %{ix86}
#
# kernel-desktop586: i586, smp-alternatives, 1GB
#

%if %build_desktop586
%define summary_desktop586 Linux kernel for desktop use with i586 & 1GB RAM
%define info_desktop586 This kernel is compiled for desktop use, single or \
multiple i586 processor(s)/core(s) and less than 1GB RAM (usually 870-900MB \
detected), using voluntary preempt, CFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%mkflavour desktop586
%endif
%endif

#
# kernel-desktop: i686, smp-alternatives, 4 GB / x86_64
#

%if %build_desktop
%ifarch %{ix86}
%define summary_desktop Linux Kernel for desktop use with i686 & 4GB RAM
%define info_desktop This kernel is compiled for desktop use, single or \
multiple i686 processor(s)/core(s) and less than 4GB RAM, using HZ_1000, \
voluntary preempt, CFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%else
%define summary_desktop Linux Kernel for desktop use with %{_arch}
%define info_desktop This kernel is compiled for desktop use, single or \
multiple %{_arch} processor(s)/core(s), using HZ_1000, voluntary preempt, \
CFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%endif
%mkflavour desktop
%endif

#
# kernel-laptop: i686, smp-alternatives, 4GB / x86_64
#

%if %build_laptop
%ifarch %{ix86}
%define summary_laptop Linux kernel for laptop use with i686 & 4GB RAM
%define info_laptop This kernel is compiled for laptop use, single or \
multiple i686 processor(s)/core(s) and less than 4GB RAM, using HZ_100 \
to save battery, voluntary preempt, CFS cpu scheduler, cfq i/o scheduler \
and some other laptop-specific optimizations. If you want to sacrifice \
battery life for performance, you better use the %{kname}-desktop. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%else
%define summary_laptop Linux kernel for laptop use with %{_arch}
%define info_laptop This kernel is compiled for laptop use, single or \
multiple %{_arch} processor(s)/core(s), using HZ_100 to save battery, \
voluntary preempt, CFS cpu scheduler, cfq i/o scheduler and some other \
laptop-specific optimizations. If you want to sacrifice battery life for \
performance, you better use the %{kname}-desktop. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%endif
%mkflavour laptop
%endif

#
# kernel-server: i686, smp-alternatives, 64 GB / x86_64
#

%if %build_server
%ifarch %{ix86}
%define summary_server Linux Kernel for server use with i686 & 64GB RAM
%define info_server This kernel is compiled for server use, single or \
multiple i686 processor(s)/core(s) and up to 64GB RAM using PAE, using \
no preempt, HZ_100, CFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%else
%define summary_server Linux Kernel for server use with %{_arch}
%define info_server This kernel is compiled for server use, single or \
multiple %{_arch} processor(s)/core(s), using no preempt, HZ_100, \
CFS cpu scheduler and cfq i/o scheduler. \
This kernel relies on in-kernel smp alternatives to switch between up & smp \
mode depending on detected hardware. To force the kernel to boot in single \
processor mode, use the "nosmp" boot parameter.
%endif
%mkflavour server
%endif

#
# kernel-source
#
%package -n %{kname}-source-%{buildrel}
Version: 	%{fakever}
Release: 	%{fakerel}
Requires: 	glibc-devel, ncurses-devel, make, gcc, perl
Summary: 	The Linux source code for %{kname}-%{buildrel}  
Group: 		Development/Kernel
Autoreqprov: 	no
Provides: 	kernel-source = %{kverrel}, kernel-devel = %{kverrel}

%description -n %{kname}-source-%{buildrel}
The %{kname}-source package contains the source code files for the Mandriva
Linux kernel. Theese source files are only needed if you want to build your
own custom kernel that is better tuned to your particular hardware.

If you only want the files needed to build 3rdparty (nVidia, Ati, dkms-*,...)
drivers against, install the *-devel-* rpm that is matching your kernel.

%common_description_info

%post -n %{kname}-source-%{buildrel}
for i in /lib/modules/%{kversion}-{desktop586,desktop,laptop,server}-%{buildrpmrel}; do
        if [ -d $i ]; then
		rm -f $i/{build,source}
                ln -sf /usr/src/linux-%{kversion}-%{buildrpmrel} $i/build
                ln -sf /usr/src/linux-%{kversion}-%{buildrpmrel} $i/source
        fi
done
cd /usr/src
rm -f linux
ln -snf linux-%{kversion}-%{buildrpmrel} linux

%preun -n %{kname}-source-%{buildrel}
for i in /lib/modules/%{kversion}-{desktop586,desktop,laptop,server}-%{buildrpmrel}/{build,source}; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
if [ -L /usr/src/linux ]; then
	if [ "$(readlink /usr/src/linux)" = "linux-%{kversion}-%{buildrpmrel}" ]; then
		rm -f /usr/src/linux
	fi
fi
exit 0

#
# kernel-source-latest: virtual rpm
#
%package -n %{kname}-source-latest
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Virtual rpm for latest %{kname}-source
Group:   	Development/Kernel
Requires: 	%{kname}-source-%{buildrel}

%description -n %{kname}-source-latest
This package is a virtual rpm that aims to make sure you always have the
latest %{kname}-source installed...

%common_description_info

#
# kernel-doc: documentation for the Linux kernel
#
%package -n %{kname}-doc
Version: 	%{kversion}
Release: 	%{rpmrel}
Summary: 	Various documentation bits found in the %{kname} source
Group: 		Books/Computer books

%description -n %{kname}-doc
This package contains documentation files from the %{kname} source. 
Various bits of information about the Linux kernel and the device drivers 
shipped with it are documented in these files. You also might want install 
this package if you need a reference to the options that can be passed to 
Linux kernel modules at load time.

%common_description_info

#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c
%setup -q -n %top_dir_name -D -T -a100

%define patches_dir ../%{patch_ver}/

cd %src_dir
%if %kpatch
%patch1 -p1
%endif
%if %kstable
%patch1 -p1
%endif

%{patches_dir}/scripts/apply_patches

# PATCH END


#
# Setup Begin
#

# Prepare all the variables for calling create_configs

%if %build_debug
%define debug --debug
%else
%define debug --no-debug
%endif

%{patches_dir}/scripts/create_configs %debug --user_cpu="%{target_arch}"

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name '*~' -o -name '*.orig' -o -name '*.append' |xargs rm -f


%build
# Common target directories
%define _kerneldir /usr/src/linux-%{kversion}-%{buildrpmrel}
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _efidir %{_bootdir}/efi/mandriva

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}


PrepareKernel() {
	name=$1
	extension=$2
	echo "Make dep for kernel $extension"
	%smake -s mrproper

	if [ $name = ""]; then
		cp arch/%{target_arch}/defconfig-desktop .config
	else
		cp arch/%{target_arch}/defconfig-$name .config
	fi
	
	# make sure EXTRAVERSION says what we want it to say
	%if %kstable
		LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = .%{kstable}-$extension/" Makefile
	%else
		LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -$extension/" Makefile
	%endif
	### FIXME MDV bugs #29744, #29074, will be removed when fixed upstream
	LC_ALL=C perl -p -i -e "s/^source/### source/" drivers/crypto/Kconfig
	
	%smake oldconfig
}


BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"

	%kmake all

	# Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer

        %ifarch ppc powerpc
	        cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
		%ifarch ppc
			cp -f arch/ppc/boot/images/zImage.chrp-rs6k %{temp_boot}/vmlinuz-rs6k-$KernelVer
		%endif
	%endif
	%ifarch sparc sparc64
		gzip -9c vmlinux > %{temp_boot}/vmlinuz-$KernelVer
	%else
		cp -f arch/%{target_arch}/boot/bzImage %{temp_boot}/vmlinuz-$KernelVer
	%endif

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install 
}


SaveDevel() {
	devel_flavour=$1

	DevelRoot=/usr/src/linux-%{kversion}-$devel_flavour-%{buildrpmrel}
	TempDevelRoot=%{temp_root}$DevelRoot

	mkdir -p $TempDevelRoot
	for i in $(find . -name Makefile -o -name Makefile-* -o -name Makefile.*); do cp -R --parents $i $TempDevelRoot;done
	for i in $(find . -name Kconfig -o -name Kconfig.* -o -name Kbuild -o -name Kbuild.*); do cp -R --parents $i $TempDevelRoot;done
	cp -fR include $TempDevelRoot
	cp -fR scripts $TempDevelRoot
	cp -fR arch/%{target_arch}/kernel/asm-offsets.{c,s} $TempDevelRoot/arch/%{target_arch}/kernel/
	%ifarch %{ix86}
	cp -fR arch/%{target_arch}/kernel/sigframe.h $TempDevelRoot/arch/%{target_arch}/kernel/
	%endif
	cp -fR .config Module.symvers $TempDevelRoot
	cp -fR 3rdparty/mkbuild.pl $TempDevelRoot/3rdparty
	
	# Needed for truecrypt build (Danny)
	cp -fR drivers/md/dm.h $TempDevelRoot/drivers/md/
	
	for i in alpha arm arm26 avr32 blackfin cris frv h8300 ia64 mips m32r m68knommu parisc s390 sh sh64 v850 xtensa; do
		rm -rf $TempDevelRoot/arch/$i
		rm -rf $TempDevelRoot/include/asm-$i
	done
	
	# ppc needs only m68k headers
	rm -rf $TempDevelRoot/arch/m68k
		
	%ifnarch %{ix86} x86_64
		rm -rf $TempDevelRoot/arch/i386
		rm -rf $TempDevelRoot/arch/x86_64
		rm -rf $TempDevelRoot/include/asm-i386
		rm -rf $TempDevelRoot/include/asm-x86_64
	%endif
	%ifnarch ppc powerpc
		rm -rf $TempDevelRoot/arch/ppc
		rm -rf $TempDevelRoot/arch/powerpc
		rm -rf $TempDevelRoot/include/asm-m68k
		rm -rf $TempDevelRoot/include/asm-ppc
		rm -rf $TempDevelRoot/include/asm-powerpc
	%endif
	%ifnarch sparc sparc64
		rm -rf $TempDevelRoot/arch/sparc
		rm -rf $TempDevelRoot/arch/sparc64
		rm -rf $TempDevelRoot/include/asm-sparc
		rm -rf $TempDevelRoot/include/asm-sparc64
	%endif

	
	# fix permissions
	chmod -R a+rX $TempDevelRoot

	kernel_devel_files=../kernel_devel_files.$devel_flavour
	

### Cteate the kernel_devel_files.*
cat > $kernel_devel_files <<EOF
%defattr(-,root,root)
%dir $DevelRoot
%dir $DevelRoot/arch
%dir $DevelRoot/include
$DevelRoot/3rdparty
$DevelRoot/Documentation
%ifarch %{ix86} x86_64
$DevelRoot/arch/i386
$DevelRoot/arch/x86_64
%endif
%ifarch ppc powerpc
$DevelRoot/arch/powerpc
$DevelRoot/arch/ppc
%endif
%ifarch sparc sparc64
$DevelRoot/arch/sparc
$DevelRoot/arch/sparc64
%endif
$DevelRoot/arch/um
$DevelRoot/block
$DevelRoot/crypto
$DevelRoot/drivers
$DevelRoot/fs
$DevelRoot/include/Kbuild
$DevelRoot/include/acpi
$DevelRoot/include/asm
$DevelRoot/include/asm-generic
%ifarch %{ix86} x86_64
$DevelRoot/include/asm-i386
$DevelRoot/include/asm-x86_64
%endif
%ifarch powerpc ppc
$DevelRoot/include/asm-m68k
$DevelRoot/include/asm-powerpc
$DevelRoot/include/asm-ppc
%endif
%ifarch sparc sparc64
$DevelRoot/include/asm-sparc
$DevelRoot/include/asm-sparc64
%endif
$DevelRoot/include/asm-um
$DevelRoot/include/config
$DevelRoot/include/crypto
$DevelRoot/include/keys
$DevelRoot/include/linux
$DevelRoot/include/math-emu
$DevelRoot/include/media
$DevelRoot/include/mtd
$DevelRoot/include/net
$DevelRoot/include/pcmcia
$DevelRoot/include/rdma
$DevelRoot/include/rxrpc
$DevelRoot/include/scsi
$DevelRoot/include/sound
$DevelRoot/include/video
$DevelRoot/init
$DevelRoot/ipc
$DevelRoot/kernel
$DevelRoot/lib
$DevelRoot/mm
$DevelRoot/net
$DevelRoot/scripts
$DevelRoot/security
$DevelRoot/sound
$DevelRoot/usr
$DevelRoot/.config
$DevelRoot/Kbuild
$DevelRoot/Makefile
$DevelRoot/Module.symvers
%doc README.MandrivaLinux
%doc README.kernel-sources
EOF


### Create -devel Post script on the fly
cat > $kernel_devel_files-post <<EOF
if [ -d /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/{build,source}
	ln -sf $DevelRoot /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/build
	ln -sf $DevelRoot /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/source
fi
EOF


### Create -devel Preun script on the fly
cat > $kernel_devel_files-preun <<EOF
if [ -L /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/build ]; then
	rm -f /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}$devel_cpu/source ]; then
	rm -f /lib/modules/%{kversion}-$devel_flavour-%{buildrpmrel}/source
fi
exit 0
EOF
}


CreateFiles() {
	kernel_flavour=$1
	
	kernel_files=../kernel_files.$kernel_flavour
	
### Create the kernel_files.*
cat > $kernel_files <<EOF
%defattr(-,root,root)
%{_bootdir}/System.map-%{kversion}-$kernel_flavour-%{buildrpmrel}
%{_bootdir}/config-%{kversion}-$kernel_flavour-%{buildrpmrel}
%{_bootdir}/vmlinuz-%{kversion}-$kernel_flavour-%{buildrpmrel}
%dir %{_modulesdir}/%{kversion}-$kernel_flavour-%{buildrpmrel}/
%{_modulesdir}/%{kversion}-$kernel_flavour-%{buildrpmrel}/kernel
%{_modulesdir}/%{kversion}-$kernel_flavour-%{buildrpmrel}/modules.*
%doc README.MandrivaLinux
%doc README.kernel-sources
EOF


### Create kernel Post script
cat > $kernel_files-post <<EOF
/sbin/installkernel %{kversion}-$kernel_flavour-%{buildrpmrel}
pushd /boot > /dev/null
if [ -L vmlinuz-$kernel_flavour ]; then
	rm -f vmlinuz-$kernel_flavour
fi
ln -sf vmlinuz-%{kversion}-$kernel_flavour-%{buildrpmrel} vmlinuz-$kernel_flavour
if [ -L initrd-$kernel_flavour.img ]; then
	rm -f initrd-$kernel_flavour.img
fi
ln -sf initrd-%{kversion}-$kernel_flavour-%{buildrpmrel}.img initrd-$kernel_flavour.img
popd > /dev/null
%if %build_devel
if [ -d /usr/src/linux-%{kversion}-$kernel_flavour-%{buildrpmrel} ]; then
	rm -f /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/{build,source}
	ln -sf /usr/src/linux-%{kversion}-$kernel_flavour-%{buildrpmrel} /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/build
	ln -sf /usr/src/linux-%{kversion}-$kernel_flavour-%{buildrpmrel} /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
EOF


### Create kernel Preun script on the fly
cat > $kernel_files-preun <<EOF
/sbin/installkernel -R %{kversion}-$kernel_flavour-%{buildrpmrel}
pushd /boot > /dev/null
if [ -L vmlinuz-$kernel_flavour ]; then
	if [ \$(readlink vmlinuz-$kernel_flavour) = "vmlinuz-%{kversion}-$kernel_flavour-%{buildrpmrel}" ]; then
		rm -f vmlinuz-$kernel_flavour
	fi
fi
if [ -L initrd-$kernel_flavour.img ]; then
	if [ \$(readlink initrd-$kernel_flavour.img) = "initrd-%{kversion}-$kernel_flavour-%{buildrpmrel}.img" ]; then
		rm -f initrd-$kernel_flavour.img
	fi
fi
popd > /dev/null
%if %build_devel
if [ -L /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/build ]; then
	rm -f /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/build
fi
if [ -L /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/source ]; then
	rm -f /lib/modules/%{kversion}-$kernel_flavour-%{buildrpmrel}/source
fi
%endif
exit 0
EOF


### Create kernel Postun script on the fly
cat > $kernel_files-postun <<EOF
/sbin/kernel_remove_initrd %{kversion}-$kernel_flavour-%{buildrpmrel}
EOF
}


CreateKernel() {
	flavour=$1

	PrepareKernel $flavour $flavour-%{buildrpmrel}

	BuildKernel %{kversion}-$flavour-%{buildrpmrel}
	%if %build_devel
		SaveDevel $flavour
	%endif
	CreateFiles $flavour
}


###
# DO it...
###


# Create a simulacro of buildroot
rm -rf %{temp_root}
install -d %{temp_root}


#make sure we are in the directory
cd %src_dir

%ifarch %{ix86}
%if %build_desktop586
CreateKernel desktop586
%endif
%endif

%if %build_desktop
CreateKernel desktop
%endif

%if %build_laptop
CreateKernel laptop
%endif

%if %build_server
CreateKernel server
%endif


# We don't make to repeat the depend code at the install phase
%if %build_source
    PrepareKernel "" %{buildrpmrel}custom
%smake -s prepare
%smake -s scripts
%endif


###
### install
###
%install
install -m 644 %{SOURCE4}  .
install -m 644 %{SOURCE5}  .

cd %src_dir

# Directories definition needed for installing
%define target_source %{buildroot}%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source} 

tar cf - . | tar xf - -C %{target_source}
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship
# first architecture files
for i in alpha arm arm26 avr32 blackfin cris frv h8300 ia64 mips m32r m68knommu parisc s390 sh sh64 v850 xtensa; do
	rm -rf %{target_source}/arch/$i
	rm -rf %{target_source}/include/asm-$i
done

# ppc needs only m68k headers
rm -rf %{target_source}/arch/m68k
		
%ifnarch %{ix86} x86_64
	rm -rf %{target_source}/arch/i386
	rm -rf %{target_source}/arch/x86_64
	rm -rf %{target_source}/include/asm-i386
	rm -rf %{target_source}/include/asm-x86_64
%endif
%ifnarch ppc powerpc
	rm -rf %{target_source}/arch/ppc
	rm -rf %{target_source}/arch/powerpc
	rm -rf %{target_source}/include/asm-m68k
	rm -rf %{target_source}/include/asm-ppc
	rm -rf %{target_source}/include/asm-powerpc
%endif
%ifnarch sparc sparc64
	rm -rf %{target_source}/arch/sparc
	rm -rf %{target_source}/arch/sparc64
	rm -rf %{target_source}/include/asm-sparc
	rm -rf %{target_source}/include/asm-sparc64
%endif

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd,.mailmap,.missing-syscalls.d}

#endif %build_source
%endif

# gzipping modules
find %{target_modules} -name "*.ko" | xargs gzip -9

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be
for i in %{target_modules}/*; do
	rm -f $i/build $i/source $i/modules.*
done

# sniff, if we gzipped all the modules, we change the stamp :(
# we really need the depmod -ae here
pushd %{target_modules}
for i in *; do
	/sbin/depmod -u -ae -b %{buildroot} -r -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating module.description for $i"
	modules=`find . -name "*.ko.gz"`
	echo $modules | xargs /sbin/modinfo \
	| perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' > modules.description
	popd
done
popd


###
### clean
###
%clean
rm -rf %{buildroot}


# We don't want to remove this, the whole reason of its existence is to be 
# able to do several rpm --short-circuit -bi for testing install 
# phase without repeating compilation phase
#rm -rf %{temp_root} 

###
### source and doc file lists
###

%if %build_source
%files -n %{kname}-source-%{buildrel}
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/3rdparty
%{_kerneldir}/Documentation
%ifarch %{ix86} x86_64
%{_kerneldir}/arch/i386
%{_kerneldir}/arch/x86_64
%endif
%ifarch powerpc ppc
%{_kerneldir}/arch/powerpc
%{_kerneldir}/arch/ppc
%endif
%ifarch sparc sparc64
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%endif
%{_kerneldir}/arch/um
%{_kerneldir}/block
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/fs
%{_kerneldir}/include/Kbuild
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm
%{_kerneldir}/include/asm-generic
%ifarch %{ix86} x86_64
%{_kerneldir}/include/asm-i386
%{_kerneldir}/include/asm-x86_64
%endif
%ifarch powerpc ppc
%{_kerneldir}/include/m68k
%{_kerneldir}/include/powerpc
%{_kerneldir}/include/ppc
%endif
%ifarch sparc sparc64
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%endif
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/config
%{_kerneldir}/include/crypto
%{_kerneldir}/include/keys
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/media
%{_kerneldir}/include/mtd
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/rdma
%{_kerneldir}/include/rxrpc
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/scripts
%{_kerneldir}/security
%{_kerneldir}/sound
%{_kerneldir}/usr
%{_kerneldir}/.config
%{_kerneldir}/.gitignore
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Kbuild
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
%{_kerneldir}/REPORTING-BUGS
%doc README.MandrivaLinux
%doc README.kernel-sources
#endif build_source

%files -n %{kname}-source-latest
%defattr(-,root,root)

%endif

%if %build_doc
%files -n %{kname}-doc
%defattr(-,root,root)
%doc linux-%{tar_ver}/Documentation/*
%endif

%changelog
* Wed Sep 26 2007 Luiz Capitulino <lcapitulino@mandriva.com.br> 2.6.22.9-1mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com.br>
    - 2.6.22.9
    - Revert DU21_remove_anydata_e100a_from_option.patch: just removing the ID
      doesn't fix the real problem and break working devices (see #31631 for more
      information).

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - bcm43xx: fix log flooding with ifplugd when firmware is not
      available (#33969)
    - Add quirk to disable ISOC transfers for device
      "ID 1131:1001 Integrated System Solution Corp. KY-BT100 Bluetooth
      Adapter" (#30638)
    - Add upstream fix "libata: clean up horkage handling". Probably
      needed to really fix #32076, and we must apply it anyway after
      adding BROKEN_HPA horkage support patch
    - x86_64 config:
      * enable p4-clockmod module support, reported by Per yvind Karlsen;
      * enable abit uguru sensors module.

* Mon Sep 24 2007 Luiz Capitulino <lcapitulino@mandriva.com.br> 2.6.22.7-1mdv2008.0
  o Thomas Backlund <tmb@mandriva.org>
    - update drbd to 8.0.6 (#33105)
    - disable the AnyData cdma id from option module as it does not work (#31631)
    - fix AppArmor return-code and rejected_mask (from John Johansen @ suse)
    - have only full kernel-source provide /usr/src/linux symlink

  o Luiz Capitulino <lcapitulino@mandriva.com.br>
    - PCI: Fix boot-time hang on G31/G33 PC (#31632 thanks to Pacho Ramos)
    - Enable drbd compilation on kernel-server

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Updated to 2.6.22.7, security fix only release (CVE-2007-4573).
    - Upstream bugfixes/new ids from 2.6.23-rcX:
      * intel-agp: Fix i830 mask variable that changed with G33 support;
      * pci: fix unterminated pci_device_id lists;
      * i386: Use global flag to disable broken local apic timer on AMD
        CPUs. This seems to fix a real issue here, without this patch
        a turion laptop gets apic/interrupt errors and misc kernel
        panics;
      * pata_marvell: Add more identifiers;
      * libata: Update the blacklist with a few more devices;
      * ahci: add ATI SB800 PCI IDs;
      * myri10ge: Add support for PCI device id 9.
    - Alsa updates: add missing support for ASUS A7J and nvidia MCP79 to
      hda_intel driver (from alsa repository, reported by Thierry Vignaud).
    - Included ipw3945 in kernel: as reported by many users works better
      than current iwl3945 we use, and we can keep both with current
      mandriva ldetect/module-init-tools (preferred aliases). As talked
      with Olivier Blin seems the better approach right now.
    - Fixed /usr/src/linux symlink check when removing kernel-source
      package, as reported by Andrey Borzenkov on kernel-discuss ML.
    - Enable build of kernel-doc package, reported by Pacho Ramos on
      Cooker ML.

  o Olivier Blin <blino@mandriva.com>
    - enable Conexant 2388x (bt878 successor) support on x86_64

* Wed Sep 19 2007 Luiz Capitulino <lcapitulino@mandriva.com.br> 2.6.22.6-3mdv2008.0
  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - create_configs (config_x86_highmem): implement support for highmem
      64GB setting (closes #33585). Also it's needed to set
      I2O_EXT_ADAPTEC_DMA64 when using it.
    - Added back wireless acx driver (#31539). Thanks to Adam Pigg and
      Adam Williamson for pointers and help.
    - Updated alsa subsystem again, with more bugfixes and new hardware
      support, matches closely alsa 1.0.15rc2 (#33489). Also added some
      more updates after it from hg repository:
      * add support for Asus M2A-VM HDMI and Abit IP35-PRO;
      * sc6000 minor fixes;
      * Dell laptop updates.
    - Upstream bugfixes/enhancements (already in 2.6.23-rcX):
      * ATA device blacklist additions (drives with NCQ/DMA issues);
      * Bugfix for DMA mode on VT6421 PATA port;
      * PATA support for VIA VX800;
      * 945/965GME and G33 intel-agp fixes;
      * Fix broken pata_via cable detection;
      * pata_sis timing fixes;
      * pata_it821x: fix lost interrupt with atapi devices;
      * ata_piix: add sata support for Intel Tolapai;
      * more pata_hpt{37x|3x2n} clock fixes;
      * sata_mv: add pci ids for Hightpoint RocketRaid 1740 and 1742;
      * pata_cs5520: fix probe bug regression introduced in 2.6.22;
      * usb storage: updates/additions to unusual_devs.h;
      * USB: fix support for Dell Wireless Broadband (aka WWAN);
      * forcedeth: add mcp73 support;
      * forcedeth: don't rely on bios to get MAC address order, this
        fixes problems with broken bioses on some Asus boards (like M2N)
        and possibly others;
      * VIA P4M900 support for via-agp;
      * drm/via: Fix dmablit when blit queue is full
        (http://bugs.freedesktop.org/show_bug.cgi?id=11542);
      * usb device additions (new id/support): Samsung X180 China
        cellphone, cdc subset support for Mavell vendor/product ID,
        HUAWEI E220 HSDPA modem, ACER S10 palm device (visor), Dell
        HSDPA 5520;
      * fmvj18x_cs, pcnet_cs: new ids of lan&multifunction cards (NEC
        PK-UG-J001, Panasonic CF-VML201 Panasonic TO-PDL9610,
        MICRO-RESEARCH MC336LAN);
      * sisusbvga: add product ID for Targus ACP50US;
      * run k8t_sound_hostbridge quirk only when needed;
      * unhide SMBus on Compaq Deskpro EP 401963-001 motherboard;
      * ftdi_sio: support new product based on the FTDI 232R USB/Serial;
      * ata_piix: fix pio/mwdma programming;
      * jmicron: PIO fixes (thanks to Thierry Vignaud for pointing
        this), can fix #33043.
    - Fix warning when deregistering acpi dock module (#32337). Added
      patches already upstream, thanks to Danny Tholen for tracking one
      of the commits.

  o Thomas Backlund <tmb@mandriva.org>
    - Really fix /usr/src/linux symlinking on devel rpms (#33559)
    - update unionfs to 2.1.3

  o Olivier Blin <blino@mandriva.com>
    - unionfs: do not update mtime if there is no upper branch for the inode 
      (fix bug with live systems)

  o Luiz Capitulino <lcapitulino@mandriva.com.br>
    - kernel-server: defaults number of uarts to 32 (#24924)

* Thu Sep 06 2007 Luiz Capitulino <lcapitulino@mandriva.com.br> 2.6.22.6-2mdv2008.0
  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Fixed bug in CE02_acpi-dsdt-initrd-v0.8.4-2.6.21.patch: don't load
      initrd twice, as this causes unpredicted behavior
    - Added some fixes for iwlwifi and b43, from wireless-dev
    - Added patch for kvm that fixes solaris guests (upstream sf.net
      bug #1773613)
    - Add two more ids for some zd1211rw wireless devices, commits from
      wireless-dev tree
    - Added bugfixes and Eagle IV support to ueagle-atm, as reported by
      Olivier Blin on kernel-discuss ML.

  o Luiz Capitulino <lcapitulino@mandriva.com.br>
    - libata: implement BROKEN_HPA horkage and apply it to affected drives
      (#32076)
    - pata_hpt37x: Fix 2.6.22 clock PLL regression (thanks to Pacho Ramos)
    - USB: add unusual_devs for Nikon devices D50, D80 and D100
      (thanks to Pacho Ramos)
    - USB: Adding support for HTC Smartphones to ipaq (thanks to Pacho Ramos)
    - Fix prefix on FS4 and FS5 (should be FS04 and FS05 respectively), also
      some minor changes in the series file
    - hda-intel: fix codec detection (thanks to Danny Tholen)

  o Thomas Backlund <tmb@mandriva.org>
    - fix AppArmor syslog logging (AppArmor svn rev 961)
    - readd linux prefix to kernel source/devel tree in /usr/src (#33239)
    - readd /usr/src/linux symlink pointing at latest installed 
      source/devel rpm (#33239)

* Tue Sep 04 2007 Luiz Capitulino <lcapitulino@mandriva.com.br> 2.6.22.6-1mdv2008.0
  o Thomas Backlund <tmb@mandriva.org>
    - add obsoletes/provides to the -latest virtual rpms to allow automatic
      updating to the new kernel-flavours (Big thanks to Anssi for the help):
      * kernel-desktop586-latest obsoletes/provides kernel-legacy-latest
      * kernel-desktop-latest obsoletes/provides kernel-latest
      * kernel-server-latest obsoletes/provides kernel-enterprise-latest
      * kernel-desktop-devel-latest obsoletes/provides kernel-source-stripped-latest
    - update to kernel.org 2.6.22.6
    - update AppArmor to 2.1.0 prerelease (SuSe 10_3 branch, commit 942)
    - redo unionfs AppArmor vfs buildfix (initial patch for 2.1 by 
      John Johansen <jjohansen@suse.de>
    - enable USB_SUSPEND only on laptop kernels, as it causes to much
      regressions for normal users, but is a tradeoff for laptop users (#33089)

  o Pixel <pixel@mandriva.com>
    - Call installkernel without -L since we are the main kernel

  o Luiz Capitulino <lcapitulino@mandriva.com.br>
    - ext3/4 orphan list debug support and corruption fix (#32527)
    - drop lguest: current version is buggy, and it would take sometime to
      get it in good shape (missing user-space support too)

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Disabled ath5k module, doesn't work now for release, conflicts
      with madwifi.

* Thu Aug 30 2007 Luiz Capitulino <lcapitulino@mandriva.com.br> 2.6.22.5-1mdv2008.0
  o Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - Updated to version 2.6.22.5, drop already applied
      ahci_SB700_support patch
    - Updated alsa to latest 2.6.23 code, dropped already applied
      patches
    - Added back legacy ralink drivers (the ones softmac based)
    - Fixup RTC selection in i386/x86_64/alpha configs:
      * Disabled CONFIG_RTC to allow rtc_cmos to be used. Enable generic
        rtc emulation (plus RTC_UIE emulation) in its place
      * Don't enable CONFIG_RTC_INTF_PROC because it conflicts with
        /proc/driver/rtc already provided by CONFIG_GEN_RTC
      * Enable RTC UIE emulation on dev interface for new rtc framework
    - Drop bcm43xx-pci-neuter patch, bcm43xx allowed to all supported
      devices again as module selection will be ldetect's task
    - Removed disable-zd1211rw-mac80211 patch, just disable
      zd1211rw-mac80211 in config instead (zd1211rw more uptodate, no
      need to keep it enabled)
    - Updated wireless subsystem to latest wireless-dev
    - Updated kvm to version 36

  o Luiz Capitulino <lcapitulino@mandriva.com.br>
    - USB: add the ZTE ZXDSL 852 device ID for cxacru (#32707)

  o Thomas Backlund <tmb@mandriva.org>
    - update CFS scheduler to v 20.5
    - update lguest patch for new CFS scheduler
    - drop add-above-background-function patch, merged in CFS
    - update unionfs to 2.1.2
    - update acer_acpi to 0.7
    - use defconfig-desktop as default configs/arch.config, and simplify
      create_configs script accordingly
    - drop xen, xbox and boot support from create_configs as the
      kernel spec does not support them either anymore
    - add virtual kernel rpm for the installer to automatically
      install the default kernel-desktop rpm
    - fix #29744, #29074 in a cleaner way by disabling the sourcing of 
      arch/s390/crypto/Kconfig
    - update kernel descriptions and summarys
    - make kernel-doc name unversioned
    - spec cleanups and typo fixes
    - drop alpha, ia64 support

* Fri Aug 24 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22.3-1mdv2008.0
  o Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - More wireless updates, fixes/changes for b43 module and ssb from
      wireless-dev
    - Don't allow bcm43xx and b43 coexist for same devices, limit the
      set of devices supported to only one module (patch from fedora)
    - Disable zd1211rw-mac80211 module, use only zd1211rw (to avoid the
      same case like b43 x bcm43xx, and zd1211rw probably is more
      stable)
    - Update ACPI battery and ec with changes that will come in 2.6.23,
      battery update fixes battery reading status deadlock on some
      notebooks when the machine is turned on without ac cable

  o Thomas Backlund <tmb@mandriva.org>
    - change to kernel-tmb spec and naming and kernel.org versioning
    - adapt scripts and Makefile to the new naming scheme

* Thu Aug 16 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22-6mdv2008.0
  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Updated wireless subsystem to the current state of upstream Linus
      git and wireless-dev, also this obsoletes some previous added
      patches
    - Added external ssb support for b44
    - Added patch for http://bugzilla.kernel.org/show_bug.cgi?id=7995
      (don't restore reserved memory after hibernation, otherwise some
       ACPI status changes while suspending to disk couldn't be updated)

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - HID: fix autocentering of PID devices (Anssi Hannula <anssi@mandriva.org>)
    - Really use CFQ as the default I/O scheduler (trem <trem@mandriva.org>)

  o Thomas Backlund <tmb@mandriva.org>
    - add patch AB03: update to kernel.org 2.6.22.3
    - add patch DN03: fix Realtek id due to upstream nVidia PHY renaming.
    - add patch DS02: fix amd sb700 and add sb800 smbus support (#32568)
    
* Fri Aug 10 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22-5mdv2008.0
  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Updated iwlwifi to the latest git snapshot
      (06deb1b0e1b9f44ac38c0b0c23a9bb715bb4224f)

  o Thomas Backlund <tmb@mandriva.org>
    - add patch AB02: kernel.org 2.6.22.2
    - drop patches CE07, DI11, HR01, SR01: merged upstream
    - rediff patch SA03 to work with 2.6.22.2

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Use CFQ as the default I/O scheduler

* Wed Aug  8 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22-4mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - e1000: Update to 7.6.5 (#32324)

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Provide pci_ids.h to user space, needed by ldetect, reported by
      Thierry Vignaud
    - Fix issue of some r8169 boards not activating link, using patch
      posted on netdev ML by Francois Romieu (r8169_link_down_fix patch)
    - Disabled CONFIG_DEBUG_SHIRQ on arches where it was enabled, as
      this can cause problems with some modules, like r8169 (see
      https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=242572)
    - update_configs: fix usage typo

  o Thomas Backlund <tmb@mandriva.org>
    - disable DEBUG_SLAB, as it's bad for performance, especially
      under heavier loads
    - add patch AI01: picopower irq router support
    - add patch AI02: Toshiba Equium A60 needs pci=assign-busses (#18989)
    - fix kernel-source-stripped symlinks generation when the -stripped rpm 
      is installed before the kernel (#32236)
    - add patch CE07: fix acpi dock unload oops (#32337)

* Tue Jul 31 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22-3mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - x86_64: Enable saa7134 drivers (#16206)
    - SMBus: Support for AMD/ATI SB700 chipset (#31450)
    - AHCI: IDs for ATI SB700 (#31884)

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Fix for 'make prepare' not working anymore on
      kernel-source-stripped after addition of lguest patch (#31958)
    - Added upstream patch "Add a PCI ID for santa rosa's PATA
      controller"
      (DI11_Add-a-PCI-ID-for-santa-rosa-PATA-controller.patch)

* Fri Jul 20 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22-2mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Usb-audio: another Logitech camera/microphone ID match
      (patch from Daniel Drake <dsd@gentoo.org>)
    - hda-codec: Add quirk for Asus P5LD2
      (path from Claudio Matsuoka <cmatsuoka@gmail.com>)

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Added SR01_serial_reg-header.patch, to export serial_reg.h to user
      space, needed at least for xosview
    - Added "cherry-picked" upstream hrtimers fixes from
      http://www.tglx.de/projects/hrtimers/2.6.22/broken-out/:
      HR01_i386-hpet-check-if-the-counter-works.patch
      HR02_timekeeping-fixup-shadow-variable-argument.patch
      HR03_clockevents-fix-resume-logic.patch
      HR04_clockevents-fix-device-replacement.patch
      HR05_i386-pit-stop-only-when-in-periodic-or-oneshot-mode.patch

* Sun Jul 16 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.22-1mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - 2.6.22 rebase
    - lguest
    - CFS process scheduler
    - Lots of 5.1 sound fixes from Claudio Matsuoka (claudio@mandriva.com)

  o Herton Ronaldo Krzesinski <herton@mandriva.com>
    - Added patch with upstream fixes for eeprom 93cx6
      (MC75_eeprom-93cx6-misc-fixes.patch)
    - Rediffed bootsplash patch, while we don't have a definition about
      dropping it or not
    - Added latest patch additions with descriptions (if available, many
      from kernel-tmb) to series file

  o Thomas Backlund <tmb@mandriva.org>
    - set PHYSICAL_START=0x200000 on x86_64
    - use readlink instead of ls and awk in scripts, as ls broken in
      current coreutils (#31906), this also makes the scripts nicer
    - add patch AB17: fix lguest build on x86_64
    - add patch AB18: CFS update to v20 (from -rt tree)
    - rediff patch CD02: Mandriva console logo
    - add patch DI10: Wacom Bamboo Tablet support (#31831)
    - update patch MC17: update ndiswrapper to 1.47
    - add patch MC18: fix ndiswrapper Kconfig and Makefile
    - add patches MC21, MC22: squashfs buildfixes from kernel-tmb
    - update patch MC49: unionfs 2.0 2.6.22.1-u2
    - add patch MC50: fix unionfs build with AppArmor
    - update patch MC54: acer_acpi to v0.6
    - add patches MC60, MC61: drbd v8.0.4
    - add patches MC70-MC74: updated wireless drivers using the new dscape stack
      * ADMtek ADM8211, Broadcom BCM43xx, Iwlwifi, Prism64 PCI, USB
      * Ralink rt2400, rt2500, rt2500 usb, rt61, rt73
      * Realtek 8187 USB, ZyDAS ZD1211/ZD1211B USB
    - drop patch NA01: old drbd version
    - add patches MS01-MS07: Swap Prefetch
    - add patches SA01-SA44: Novell AppArmor 2.0.2 build 755
    - update defconfigs
    
* Fri Jul 06 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.21-4mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Makes kernel-source usable again for dkms packages
      (patches from Olivier Blin <blino@mandriva.com>)

* Wed Jul 04 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.21-3mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - CFS process scheduler v18
    - Fix kernel-stripped package (from Thomas Backlund <tmb@mandriva.org>)
    - First round of dropped patches, moved 26 into the 'patches-to-drop' queue
    - Rediffed several patches that doesn't apply cleanly
    - Enabled CONFIG_SECURITY and friends
    - Disabled CONFIG_IRQBALANCE (looks like it drops battery life #31725)
    - Alsa HDA codec fixes: 5.1 output on LG LW20 and HP Spartan quirk
      (from Claudio Matsuoka <cmatsuoka@gmail.com>)
    - Alsa usbaudio quirk for Roland Juno-G
      (from Claudio Matsuoka <claudio@mandriva.com>)

* Thu Jun 28 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.21-2mdv2008.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - 2.6.21.5mdv (see the patch file for more info)
    - Drop XEN
    - Drop RSBAC
    - Fix drbd provides (we're providing api = 86 now)
    - kernel-source fixes (some bits from Thomas Backlund <tmb@mandriva.org>)
    - Drakxtool conflict (patch from Thierry Vignaud <tvignaud@mandriva.com>)

* Wed Jun 20 2007 Arnaud Patard <apatard@mandriva.com> 2.6.21-1mdv2008.0
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.21 upgrade

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Minor build fix
    - Disable XEN build

* Tue Mar 27 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-14uc1mdv2007.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - PCI: pcieport-driver: remove invalid warning message

  o Arnaud Patard <apatard@mandriva.com>
    - Fix error path in usbcore
    - Don't build KVM on Xen kernels

* Fri Mar 23 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-13mdv2007.0
  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - Improve keyboard handling on Apple MacBooks

  o Arnaud Patard <apatard@mandriva.com>
    - Add -latest patch
    - Workaround a possible binutils bug in smp alternatives

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - MCP61: Add forcedeth support
    - Fix potential deadlock in driver core, this issue seems to cause USB
      hangs at boot time (#24683 Thanks to Danny danny@mailmij.org)
    - Security fix:
      * ZZ23_CVE-2007-1592_ipv6_fl_socklist_inadvertently_shared_fix.patch
        (#29821)

* Wed Mar 14 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-12mdv2007.0
  o Arnaud Patard <apatard@mandriva.com>
    - Suspend to disk speed improvements
    - Add nmi watchdog support for core2
    - Add atl1 driver
    - Update KVM (rev 4486 + selective changes)
    - Add acer_acpi
    - Update asus_acpi
    - Fix suspend on r8169, i8259A
    - Fix suspend when using ondemand governor
    - Add ide acpi support
    - Add suspend/resume support for sata_nv chipsets.

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Rename ZZ65 patch to ZZ17 and ZZ99 patch to ZZ18 (just to make my
      scripts' life easier)
    - USB: Let USB-Serial option driver handle anydata devices (#29066)
    - USB: Add PlayStation 2 Trance Vibrator driver
    - Fix bogus delay loop in video/aty/mach64_ct.c (thanks to
      Per yvind Karlsen)
    - Add MCP61 support (#29398 thanks to Pacho Ramos
      pacho@condmat1.ciencias.uniovi.es)
    - USB: fix floppy drive SAMSUNG SFD-321U/EP detected 8 times bug
      (thanks to Ednilson Miura <miura@mandriva.com>)
    - Security fixes:
      * ZZ14_CVE-2007-0958_unreadable_binaries_pt_interp_fix.patch   (#28757)
      * ZZ15_CVE-2007-0772_nfs_free_wrong_pointer_fix.patch          (#28863)
      * ZZ16_CVE-2006-6056_hfs_null_pointer_fix.patch                (#28690)
      * ZZ19_CVE-2007-0005_cm4040_cs_buffer_overflow_fix.patch       (#28634)
      * ZZ20_CVE-2007-1217_capi_debug_buffer_overflow_fix.patch      (#29067)
      * ZZ21_CVE-2007-1388_ipv6_sockglue_null_ptr_fix.patch          (#29400)
      * ZZ22_CVE-2007-1000_ipv6_getsockopt_sticky_null_ptr_fix.patch (#29401)

* Tue Feb 13 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-11mdv2007.0
  o Arnaud Patard <apatard@mandriva.com>
    - Fix SiS sata support for chips on 966/968 bridges
    - Add support for SiS968 bridges to the sis190 bridge
    - Add support for showing blocked tasks through sysrq
    - Add nozomi driver
    - Add UVC driver
    - Fix JMicron cable detection
    - Fix issues in squashfs by updating to 3.2 (#27008)

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - x86_64: Add /proc/config.gz support (CONFIG_IKCONFIG)
    - x86_64: Add stack overflow support. Disabled by default, but it's
      something good to have at hand
    - x86_64: Enable kexec
    - USB: rndis_host: fix crash while probing a Nokia S60 mobile
    - rt2570 should report itself as "rt2570" instead of "rtusb" (#24461)
    - atiixp.c: sb600 ide only has one channel (#28505 - thanks to
      Wolke <wolke.liu@amd.com>)
    - PCI: ATI sb600 sata quirk (#28363 - thanks to Wolke <wolke.liu@amd.com>)
    - read_zero_pagealigned() locking fix (thanks to Hugh Dickins
      <hugh@veritas.com>)
    - Fix umask when noACL kernel meets extN tuned for ACLs
      (thanks to Hugh Dickins <hugh@veritas.com>)
    - PowerPC: Make current preempt-safe (thanks to Hugh Dickins
      <hugh@veritas.com>)
    - Security fixes:
      * ZZ12_CVE-2007-0006_key_serial_number_collision_fix.patch (#28636)
      * ZZ13_CVE-2006-5823_cramfs_zlib_inflate.patch             (#28688)

* Fri Feb 02 2007 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-10mdv2007.0
  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - Add Ralink RT2571W/RT2671 WLAN USB support (rt73 module)

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Fix sys_msync() to report -ENOMEM as before when an unmapped area falls
      within its range, and not to overshoot (LSB regression)
    - Avoid disk sector_t overflow for >2TB ext3 filesystem
    - USB: workaround to fix HP scanners detection (#26728)
    - USB: unusual_devs.h for Sony floppy          (#28378)
    - Dropped FS06_max-symlink-to-10.patch, this patch adds security issues
      on x86_64 machines and was only needed to create Live CDs (now we
      use unionfs). Thanks to Thomas Backlund, who helped to find the
      patch (#27955)
    - Security fixes:
      * ZZ08_CVE-2006-5749_isdn_ppp_init_reset_state_timer.patch (#27802)
      * ZZ09_CVE-2006-5753_fix_bad_inode_retun_values.patch      (#27958)
      * ZZ10_CVE-2006-6053_ext3_handle_dir_corruption.patch      (#28303)
      * ZZ11_CVE-2006-4814_mincore_fix_user_access_locking.patch (#28373)

  o Arnaud Patard <apatard@mandriva.com>
    - Add preliminary ICH9 support
    - Add TI sd card reader support
    - Add RT61 driver
    - KVM update
    - Fix bttv vbi offset
    - Update RT73 and use the firmware class for RT73

* Wed Dec 27 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-9mdv2007.0
  o Arnaud Patard <apatard@mandriva.com>
    - ata_piix fix for some ICH8 port configurations.
    - Suspend/resume fixes
    - Add KVM
    - Add flush option for fat filesystems
    - X86_64 core2 rdtsc fix

* Fri Dec 19 2006 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-8mdv2007.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Dropped DA16_wacom_acpi_enable_future_usage.patch, it does brake
      CONFIG_ACPI=yes compilation seems non-sense and there's no description
      explaining why it's needed
    - Security fixes:
      * ZZ03_CVE-2006-5173_eflags_reset.patch                      (#26535)
      * ZZ04_CVE-2006-5619_ip6_flowlabel_seqfile_fix.patch         (#27034)
      * ZZ05_CVE-2006-5751_bridge_overflow_fix.patch               (#27538)
      * ZZ06_CVE-2006-6106_bluetooth_add_capi_packet_checks.patch  (#27660)
      * ZZ07_CVE-2006-5757_fs_grow_buffers_infinite_loop_fix.patch (#27033)

* Thu Dec 7 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-7mdv2007.0
  o Arnaud Patard <apatard@mandriva.com>
    - Add Marvell IDE driver
    - Add a driver for Jmicron chipsets instead of using the generic one
    - Update the sky2 driver to fix some network hang issues

* Tue Oct 24 2006 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.17-6mdv2007.0
  o Samir Bellabes <sbellabes@mandriva.com>
    - backport support for network chipset related to r8169 (r8168/r8169SC)

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - 2.6.17.14
    - Dropped DB40_sd_mmc_2gb.patch (fix also in 2.6.17.14)
    - pccard_store_cis: fix wrong error handling
      (reported by Giuseppe Ghib <ghibo@mandriva.com>)
    - x86_64: add NX mask for PTE entry
      (patch from Eduardo Habkost <ehabkost@mandriva.com>)
    - Fix snd-hda-intel OOPS (patch from Eduardo Habkost <ehabkost@mandriva.com>)
    - mach64: Explicit initialize some members of the drm_driver structure,
      otherwise NULL init will have bad side effetcs
      (patch from Couriousous <couriousous@mandriva.org>)
    - Adds Missing check for CAP_NET_ADMIN in iptables compat layer
    - Support for building .nosrc.rpm
      (patch from Thomas Backlund <tmb@mandriva.org>)
    - Security fixes
      * ZZ01_CVE-2006-4997_clip_do_not_refer_freed_skbuff.patch           (#26608)
      * ZZ02_CVE-2006-4572_netfilter_ipv6_fragmention_attacks_fixes.patch (#26745)

  o Arnaud Patard <apatard@mandriva.com>
    - Fix pcmcia unplug/eject on cards with r8169 chipsets
    - Fix libata resource conflicts detection (#23279)
    - Fix xenU crash and reenable domU boot logs.
    - Fix refcount error triggered by softwares using /proc/<pid>/auxv

* Wed Sep  6 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-5mdv2007.0
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.17-13
    - RSBAC fixlets
    - Fix JMicron SATA/PATA chipsets support (#25155)
    - Update the at76c503a usb driver (now called at76_usb) (#25278)
    - Fix reversed error test in netif_tx_trylock (#25249)
    - Fix modalias on 64bits (#25431)
    - Fix ipmi_msghandler oops on removal (#25463)
    - Replace DU04 with its upstream version
    - Disable MSI on azalia codecs to prevent IRQ troubles.
    - Disable FN keys in the i8k driver when failing to get the dell smm bios
    version. Patch from Per Oyvind Karlsen. (#21140)

  o Samir Bellabes <sbellabes@mandriva.com> 
    - cosmetic changes from Thomas Backlund <tmb@mandriva.org>

* Mon Sep 4 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-4mdv2007.0
  o Samir Bellabes <sbellabes@mandriva.com> 
    - netfilter fix - bug #24252
    - fix netfilter IFWLOG

  o Arnaud Patard <apatard@mandriva.com>
    - AHCI suspend
    - Squashfs 3.1r2
    - Fix oops on video.ko rmmod
    - SiS 966 chipsets support
    - Add support for 2Gb memory cards
    - Fix uhci list bug
    - Revert reset changes in the e1000 driver. This should fix
    the e1000 resume issues
    - Fix list usage in the sis190 driver

* Mon Aug 29 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-3mdv2007.0
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Updates drbd to 8.0pre4
    - Adds drbd-api provides (#24264)
    - Adds support for partitioned loop devices (patch from Flavio
      fbl@mandriva.com)
    - Fix double ACPI video /proc entries (patch from Danny danny@mailmij.org
      #22249)

  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.17.11
    - Alsa 1.0.12
    - Enable USB_EHCI_SPLIT_ISO (#24412)
    - Fix sparc build (#24646)
    - Fix Xen on 32bit and workaround Xen bug on 64bit.
    - Fix b44 module (#24312)
    - RSBAC 1.2.8
  
* Thu Aug 10 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-2mdv2007.0
  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - Enable HUGETLBFS
    - Factor out configs

  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.17.8
    - Alsa 1.0.12rc2
    - Add usb ids for the Testo usb device (bug #23666)
    - Add quickcam messenger driver for 2.6.18-rcX
    - ata_piix/ICH8 fixes
    - ACL support for tmpfs  (bug #24045)
    - Add DI20_initialize_hw_regs_in_setup_ports.patch from 2006-upd
    - i965 support
    - Intel iAMT redirection drivers

  o Samir Bellabes <sbellabes@mandriva.com>
    - Add support for chipset realtek 8168. (bug #23705)
    - Add netfilter ipset patch
    - Add netfilter conntrack/nat sip patch
    - Add netfilter psd patch

* Tue Jun 29 2006 Arnaud Patard <apatard@mandriva.com> 2.6.17-1mdk
    - 2.6.17.6
    - Alsa 1.0.12rc1
    - Rsbac 1.2.8(pre1)
    - New Xen snapshot
    - New wireless-2.6 snapshot (adds zd1211rw driver)
    - KGDB drop
    - e100, e1000 update
    - Via VT8251 sata support
    - vt_ar5k drop. Considered as obselete by upstream.
    - svgalib_helper drop.
    - 3rdparty updates : acerhk, drbd, dxr3, ipw3945, ivtv, lirc,
    mod_marvel, ndiswrapper

* Wed Jun 28 2006 Samir Bellabes <sbellabes@mandriva.com> 2.6.16-3mdk
  o Samir Bellabes <sbellabes@mandriva.com>
    - re-enable supermount (fix bug #23217)
    - ct_sync aka 'howto replicate the firewall'

* Mon May 22 2006 Arnaud Patard <apatard@mandriva.com> 2.6.16-2mdk
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.16.20
    - input.h : move input_device_id to mod_devicetable.h
    - Reenable unintentially disabled unionfs
    - RS02/RS11 cleanup
    - Removed bcm4400. We have the b44 module in the kernel
    - Fix usage of acpi_clear_event() in CE06
    - Enable cpufreq on SMP, disable USB_BANDWIDTH
    - Build smp and up kernel on sparc (Peroyvind)
    - Switch to GENERIC_ARCH on x86 to suppress the false warning
    about the number of cpus when using cpu hotplug
    - Add xen0 support in rhconfig.h
    - Fix freeze when using the 'live' mode of gi (instead of using the 
    clp files)
    - Activate RSBAC_INIT_DELAY to get rsbac working with all kind of
    initrd/initramfs
    - Fix fdomain vs x86_64/isa trouble

* Thu May 11 2006 Arnaud Patard <apatard@mandriva.com> 2.6.16-1mdk
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.16.16
    - Wireless update (Adds the bcm43xx driver)
    - mmc layer update (Adds the sdhci driver)
    - e1000 update
    - Xbox support outdated, so (temporary ?) removed
    - Alsa 1.0.11
    - RSBAC 1.2.6
    - New Xen snapshot
    - Updated 3rdparty
    - ipw3945

* Mon Mar 13 2006 Eduardo Pereira Habkost <ehabkost@mandriva.com> 2.6.14-2.1mdk
  o Eduardo Pereira Habkost <ehabkost@mandriva.com>
    - Change kernel-source version field to 1-1mdk, like the rest of
      the versioned packages

* Fri Mar 10 2006 Eduardo Pereira Habkost <ehabkost@mandriva.com> 2.6.14-2mdk
  o Eduardo Pereira Habkost <ehabkost@mandriva.com>
    - Avoid automatic update of kernel-source without updating the kernel:
      - Put package version on package name for kernel-source and
        kernel-source-stripped
      - Remove Obsoletes: kernel-source from kernel-source* packages
      - Closes: #21345

  o Samir Bellabes <sbellabes@mandriva.com>
    - update ipt_IFWLOG (interactive firewall)

  o Arnaud Patard <apatard@mandriva.com>
    - Fix bad update of RS11
 
* Mon Feb  7 2006 Arnaud Patard <apatard@mandriva.com> 2.6.14-1mdk
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.14.7
    - Alsa 1.0.10 and cvs update.
    - Xen update from the linux-2.6 tree. Build it now as a machine and no more
      as a different architecture.
    - Rsbac 1.2.5
    - Drbd 0.7.15
    - The bcm5700 driver is no more supported by Broadcom, thus dropping it.
    - Dropped the now merged ipw2100, ipw2200, ieee80211, fuse, hostap 3rdparty
      tarballs.
    - Changed the eagle-usb driver in favour of the to-be-merged version
    - Use now the acx driver from akpm's tree.
    - Update 3rdparty drivers : lirc, ndiswrapper, rt2400, rt2500 
    - Added rt2570 usb driver.

  o Samir Bellabes <sbellabes@mandriva.com>
    - netfilter update (DN30_netfilter_svn6470.patch)
    - unionfs 1.1.3

* Thu Nov 24 2005 Luiz Capitulino <lcapitulino@mandriva.com> 2.6.12-13.1mdk
  o Arnaud Patard <apatard@mandriva.com>
    - Fix oops when reading /proc/driver/pktcdvd/pktcdvd0

  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Added DA75_alsa_patch_realtek_fix.patch to fix a bug which makes
      some sound-cards managed by snd-hda-intel useless
 
* Mon Nov 21 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.6.12-13mdk
  o Luiz Capitulino <lcapitulino@mandriva.com>
    - Updated pl2303 usb-serial driver to support X75 and SX1 Siemens mobiles

  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - power5 & pmac64 support
    - selected fixes from 2.6.13 and beyond:
      * add r300 drm support
      * fix x86_64 idle=poll
      * fix races in libata core
      * properly fix the radeon IRQ handling code
      * properly fix the errata #122 workaround on x86_64 + add it to i386
      * merge new upstream ioctl32 compat code, thus supporting i915 as well

  o Arnaud Patard <apatard@mandriva.com>
    - Fix typo in the SiS965L support. Restore the right address for the other chipsets.

* Thu Sep  8 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.6.12-12mdk
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.12.6
    - Removed lpfc from 3rdparty as it exists in drivers/scsi/ (Thanks Svetljo 
      for pointing out this).
    - Added sata_sil24 module
    - Added SiS182 minimal support.
    - Added SiS190 driver.
    - Added support of the IDE chipset of the SiS965L boards.
    - Added various pciids from 2.6.13
    - Removed patch MD48. Now we're using udev, it breaks the prism2 module
    - Inotify fixlets
    - Removed the patch that disable the smm bios and use usb-handoff by default (Sveltjo)
    - USS725 fixes (Sveltjo)
    - execve LSB test fix (Stew)
    - Via unichrome support update (Danny)

  o Samir Bellabes
    - Add DN34_nf_rsh-conntrack_timeout.patch : 
      Fix timeout for ip_conntrack_rsh (bug #17368)
    - backport fixes for netfilter from 2.6.13-git8: (DN60-DN75 + DN80)
      * check hardware checksum in ECN, queue, TCPMSS
      * fix tcp checksum in ipt_REJECT
      * ipt_CLUSTERING: deletion, ct_related, mangling arp, memcpy_typo
      * ip6table_raw: missing owner
      * race condition in Decnet
      * optimize expected timeout
      * delete reference conntrack in ipmr
      * fix ECN tcp marking
      * fix byteorder in icmp NAT
      * fix ip6t_LOG sit tunnel logging 
      * fix masquerading index for slave connection
      * fix sysctl_tcp_low_latency
      * IFWLOG : fix bad kfree and close bug #18276 (DN33_netfilter_IFWLOG.patch)
    - Fix buffer overflow with module_param (DN76_nf_bad_param_port.patch)
      
  o Flavio Bruno Leitner <flavio@mandriva.com>
    - XEN updated to 2005-08-23

  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - increase number of supported CPUs to 32
    - add workaround for x86_64 errata #122
    - update PowerNow!K8 driver to v1.50.3 for rev.F Opteron support

* Sun Aug 28 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.6.12-11mdk
- remove obsolete patches that were fixed differently
- assorted x86_64 fixes from current git tree:
  * fix 32-bit thread debugging
  * fix TASK_SIZE for compatibility mode processes
  * fix overflow in NUMA hash function setup
  * fix bug in csum_partial_copy_generic()
  * fix HPET for systems that don't support legacy replacement
  * add support for more than 8 cores on AMD64 systems
  * tell VM about holes in nodes
  * avoid wasting IRQs

* Mon Aug 15 2005 <flavio@mandriva.com> 2.6.12-10mdk
  o Flavio Bruno Leitner <flavio@mandriva.com>
    - WARNING: Security
      Hyper-Threading enabled by default. 
      (at boot time use ht=off to disable)
    - applied patch to cpufreq support centrino.
    - updated ibm_acpi to 0.11
    - fixes to NFS
    - ACL support to NFS
    - XEN configs updated (enabled more options)

  o Samir Bellabes <sbellabes@mandriva.com>
    - 2.6.12.5

  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - fix inotify 0.24 patch
    - fix build of ndiswrapper 1.2 on x86_64
    - only build xen on x86, will enable on x86_64 later

* Thu Jul 28 2005 Arnaud Patard <apatard@mandriva.com> 2.6.12-9mdk
  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.12-4
    - Advertise the megaraid_mbox as megaraid_mbox (and not megaraid) in sysfs
    - Ndiswrapper 1.2
    - Updated ipw2100 to 1.1.2, ipw2200 to 1.0.6 
    - e100 and e1000 drivers update (e100 to 3.4.8-k2 and e1000 to 6.0.60-k2)
    - inotify 0.24
    - Set the pwc driver to use non compressed mode by default.

  o Samir Bellabes <sbellabes@mandriva.com>
    - Add MD40_rt2500_local_bh_enable_fix.patch
    - Add DN33_netfilter_IFWLOG.patch (Interactive Firewall)

  o Flavio Bruno Leitner <flavio@mandriva.com>
    - use mkinitrd without -C to force cramfs, let mkinitrd decide it.
    - add requires to module-init-tools instead of old modutils.
    - added XEN support

  o Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - resurrect legacy megaraid for { 0x9010, 0x9060, 0x1960 } (Pascal)

* Tue Jul 26 2005 Flavio Bruno Leitner <flavio@mandriva.com> 2.6.12-8mdk
  o Flavio Bruno Leitner <flavio@mandriva.com>
    - reverted latest standard wireless extensions update to v18
      (v19 isn't compatible with previous and/or maybe incomplete)
    - disabled know broken qlogicisp. (superseded by the qla1280 driver)

  o Arnaud Patard <apatard@mandriva.com>
    - 2.6.12.3. Removed the AC01 patch as 2.6.12.3 provide it.

  o Samir Bellabes <sbellabes@mandriva.com>
    - Remove DN31_netfilter-rtsp-20040302.patch (updated in DN32_netfilter_050725.patch)
    - Add DN30_kill_lockhelp.patch (use lock directly)
    - Add DN31_kill_nf_debug.patch (don't use NETFILTER_DEBUG anymore)
    - Add DN32_netfilter_050725.patch (details in svn log)

  o Gwenole Beauchesne <gbeauchesne@mandriva.com> 
    - merge and fix drm ioctl32 compat code (x86_64)

* Mon Jul 07 2005 Flavio Bruno Leitner <flavio@mandriva.com> 2.6.12-7mdk
  o Flavio Bruno Leitner <flavio@mandriva.com>
    - WARNING: removed patch to rename kernel modules 
      (Closes ticket #13428)
    - updated standard wireless extensions to v19
      (DN55_iw_we18-5.diff, DN56_iw262_we19-9.diff)
    - added support for Avermedia AVerTV GO 007 FM
      (DV52_avermedia.patch)
    - fix TPM to use BIOS instead of hardcoded memory address.
      (AC01_tpm-memory-fix.patch)

  o Arnaud Patard <apatard@mandriva.com>
    - updated to alsa 1.0.9b
    - Removed DA54_add-to-snd-intel8x0-ac97-quirk-list.patch as it has been merged.
    - inotify update to 0.23-2.6.12-15
    - Reenabled software suspend.
    - Bluez update (to 2.6.12-mh1). It adds a better HID support in bluez
    stack
    - Fixed and enable the ppscsi driver.

* Mon Jul 07 2005 Flavio Bruno Leitner <flavio@mandriva.com> 2.6.12-6mdk
  o Arnaud Patard <apatard@mandriva.com> 
    - Add support for newer versions of wpa_supplicant
    - added fixes for ipw2[12]00 drivers
    - sk98lin v8.23.1.3
    - added USB id of the Gigabyte GN-WLBZ101
    - enabled FATX support for xbox
  o Flavio Bruno Leitner <flavio@mandriva.com>
    - updated orinoco to 0.15rc2. 
    - updated to 2.6.12.2
    - enabled advansys, qlogicisp, eata_pio as module

* Mon Jul 04 2005 Flavio Bruno Leitner <flavio@mandriva.com> 2.6.12-5mdk
- updated to 2.6.12.2
  (added AB02_2.6.12.2.patch)

* Fri Jul  1 2005 Arnaud Patard <apatard@mandriva.com> 2.6.12-4mdk
- Ensure that stallion and istallion modules return an error code instead of 0 
  when something goes wrong.

* Thu Jun 23 2005 Flvio Bruno Leitner <flavio@mandriva.com> 2.6.12-3mdk
- new kernel version: 2.6.12.1
- rollback some of removed patches in 2.6.12-1mdk.

* Wed Jun 22 2005 Flvio Bruno Leitner <flavio@mandriva.com> 2.6.12-2mdk
- added drbd 0.7.11

* Wed Jun 22 2005 Flvio Bruno Leitner <flavio@mandriva.com> 2.6.12-1mdk
- new kernel version: 2.6.12
- updated bootsplash: 3.1.6
- enabled config on /proc. (/proc/config.gz)
- enabled cpufreq conservative module.
- removed ipmi smb support until be fixed for 2.6.12.
- enabled new sensors modules.
- renamed MandrakeSoft to Mandriva. (README.Mandriva too)
- fixed/improved some descriptions.
- don't use tarball for patches and scripts. (svn repos)
- added new patches:
  o MD27_tivatv-agp.patch (agp_copy_info changed)
  o MD56_pci_name-renamed.patch (s/pci->slot_name/pci_name()/)
  o MD55_i2c-client-unused-id.patch (drop unused i2c_client->id)
  o MD54_3rdpart-scsi-legacy.patch (rollback some SCSI defines)
  o JX02_reparent_public.patch (XBOX needs reparent_to_init)
  o MD53_3rdpart-removed-defined-func.patch (gcc4 fix)
  o DV32_via_mach64_drm_fixes.patch (minor field moved)
  o RS13_rsbac-2.6.12.patch (RSBAC needs task_capability_lock)
- removed already applied patches (about 55 patches)

* Mon May 30 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.11-10mdk
- disable HT by default.
- improved xbox support (stew).
- ext3_journal_unmap_buffer_race.
- CAN-2005-0750_af_bluetooth.
- CAN-2005-0400-ext2_leak.
- CAN-2005-0749_load_elf_library_DOS.
- CAN-2005-1263 binfmt_elf.
- CAN-2005-1264 raw_ioctl.
- CAN-2005-1369 sys_rw_files.

* Mon May 23 2005 Arnaud Patard <apatard@mandriva.com> 2.6.11-9mdk

- Updates: 
  - 2.6.11.10
  - Fixed ndiswrapper Makefile

- Fixes:
  - Fix build with gcc 4.0
  - Fix return codes in do_readv_writev

* Tue Apr 26 2005 Arnaud Patard <apatard@mandriva.com> 2.6.11-8mdk

- Added:
  - endian patches (Sveltjo)
  - Rename ovcam in 3rdparty to ovcam-alt (Sveltjo)
  - Add build fix for the next binutils
  - Support for sata_sil on rs480 (Gb)

- Updated:
  - Updated to 2.6.11.7
  - Lirc 0.7.1. Also fix some broken compile options
  - ipw2X00 update. Corrected also monitor mode for ipw2100.
  - saa7134 update for dvb
  - Compile mkiss as module
  - Ndiswrapper 1.2rc1 (NX support)
  - Build saa7174hl in 3rdparty/video-rivatv

* Sun Apr 10 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.11-7mdk
- sata_sil updates to v0.9
- disable pin1 APIC timer on RS480 based motherboards (e.g. HP DX5150)

* Tue Mar 22 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.11-6mdk
- enable Intel AGP support for x86-64 again (bk)
- make drm a module on x86_64 for ati drivers to work without hacks
- bring back sheep_net module for raw access to ethernet packets
- fix build on x86_64, aka remove obsolete edid/vbe stuff partly merged

* Mon Mar 21 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.11-5mdk
- several alsa fixes (arnaud).
- ipw2[12]00 wap fix (arnaud).
- disable SELINUX (we use RSBAC).
- xbox build, update spec, JX01 patch, create_configs (stew).

* Mon Mar 21 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.11-4mdk
- disable via on amd64 (for same reason does a malloc way too big).
- really compile mach64 drm.

* Sun Mar 20 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.11-3mdk
- add 2.6.11.4 patch.
- new drm for via-unichrome & ati-match64.
- bttv should work again (it is a bad idea to have two modules with the 
  same name :p ).
- new Chelsio 10GB ethernet.
- new LSI megaraid sas driver.
- compile i686-up-4GB kernel (Dothan don't work with PAE enabled).
- compile BOOT kernel (needed for cdrom yet).

* Thu Mar 10 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.11-2mdk
- merge with 10.2/x86_64 branch:
  * workaround build with icecream
  * fix ndiswrapper build
  * fix inotify compat32 code
  * fix drm/ioctl32 forward port to 2.6.11
- selected fixes from bitkeeper:
  * make IRDA devices are not really ISA devices not depend on CONFIG_ISA
  * fix boot up SMP race in timer setup on i386/x86-64

* Wed Mar 9 2005 Arnaud Patard <apatard@mandrakesoft.com> 2.6.11-1mdk

 * New kernel version
 * Include rtc in the kernel and no more in module.
 * Fixed the dl2k ethtool.

- Added :
 * usbat2 driver

- Updated :
 * Alsa 1.08 (cvs version of 20050308)
 * Ndiswrapper 1.0
 * Inotify 0.20-2 (still activated in the kernel but support
   disabled in gamin due to stability problems)
 * Bootsplash to 3.1.4-2.6.11
 * RSBAC 1.2.4
 * sk98lin 8.14
 * acx100 0.2.0-pre8 + fixes_46
 * qcusb 0.6.2
 * eagle-usb 2.2.0
 * Prevent building scsi_transport_iscsi module from the iscsi-mod
   as it's now in the kernel

- Removed :
 * AA08_isapnp_interwave.patch as it's in the BK01
   patch
 * old patches from BK (CA01,DI09,DI10,DI11,DI12,DI13,DI14,DI15,
   DI16,FS04)

* Mon Feb 21 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.10-3mdk
- rsbac is compiled but not enabled by default.

* Sun Feb 20 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.10-3mdk
  * Fix ata_piix support for ich6-r drives
  * Add ICH7 support
  * Add support for ICHX watchdog support
  * Adding command line option for a configurable delay before mounting
    root
  * Add support for ULi M5288
- Updated :
  * sk98lin
  * inotify to 0.18-rml-2.6.10-16
  * dxr3
  * ivtv to 0.2.0-rc3f
  * ipw2100 to 1.0.5
  * ipw2200 to 1.0.1
  * eagle-usb 2.1.0rc1
  * wlan-ng (prism2) 0.2.1-pre26
- Removed hpusbscsi module
- Renamed old radeon framebuffer driver to radeonfb_old (Sveltjo)
- Added a missing header in the idsn driver (Sveltjo)
- Corrected linux-mdkconfig.h
- Removed some unusefull built-in modules in the boot kernel
- Fixed config for the acerhk module as it builds only on X86 arch
- Xbox support (Stew)
- Add support for a gigabit card from USRobotic.
- Try to use the old usb enumeration scheme before trying the new one
- Add some keycodes for some keyboards made by Cherry
- Added support for the Uli M5263 network card

* Wed Feb  9 2005 Juan Quintela <quintela@mandrakesoft.com> 2.6.10-2mdk
- compile kernels:
  * UP: with NX support
  * SMP: with NX support
  * i586-up-1GB, for machines that don't support PAE.
- kernel-secure is gone, UP & SMP have rsbac as default.
- kernel-BOOT is gone, i586 should be ok for installer
- x86_64 compiles again.
- drm.biarch really integrated, no more symlinks.
- fixed lots of small problems & unused patches.
- create_configs & update_configs work again as expected.

* Mon Jan 10 2005 Arnaud Patard <apatard@mandrakesoft.com> 2.6.10-1mdk
- New upstream version
- Updated alsa with alsa CVS and added drivers from the multimedia kernels
- Updated 3rdparty : 
  * hostap
  * ipw2200
  * fuse
  * ipmi_smb and af_ipmi
  * dazuko
  * iscsi to 4.0.1.11 with a patch to rename strdup present in iscsi-session.c
    to iscsi_strdup
  * opengfs with version from http://sources.redhat.com/cluster/gfs/ 
  exported symbol (sock_getsockopt)
- Added zd1201 driver
- Added inotify
- Dropped MD34_iteraid and DI03_add-support-for-it8212-ide-controllers.patch in favour
  of Alan Cox's version
- Added delkin_cb driver from Alan Cox
- Added some functions that were suppressed from i2c-core as they were not used in 
  vanilla kernel
- Removed all MOD_INC_USE_COUNT and MOD_DEC_USE_COUNT as now it has been 
  suppressed
- Added some missing linux/version.h in alsa drivers in 3rdparty
- Fixed some broken {Kconfig,Makefile} in 3rdparty
- Added a warning when trying to do some scsi command not permitted
- Removed some call to usb_unlink_urb in eagle-usb

* Tue Dec 21 2004 Arnaud Patard <apatard@mandrakesoft.com> 2.6.9-1mdk
- Updated 3rdparty/
- Removed merged upstream patches
- Added Ralink drivers
- Updated libata (ahci support added)

* Mon Nov  8 2004 Juan Quintela <quintela@mandrakesoft.com> 2.6.8.1-21mdk
- fix unitialized skbuf with tso cards.
- CAN-2004-0814 tty_fixes.
- merge again with cooker kernel.
- remove build_acpi (always acpi now).
- fix bug #11262 (alsa mixer oops) (samir).
- Updated ipw2200 (Arnaud).
- Fix Kconfig for qlogic drives (Arnaud).
- Updated libata with fixes from 2.6.10-rc1 to correct cd-rom drives
  detection (arnaud).
- Added a patch to correct multipath problems with qla driver (Arnaud).


* Wed Nov  3 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-20mdk
- revert TARGET_CPUS change on x86_64
- config updates to x86_64:
  * enable Intel CPU microcode support
  * enable AMD 8111 (new PCI lance) support
  * change enhanced real time clock support to be built-in kernel image
  * enable JFS filesystem support
  * enable Intersil Prism GT/Duette/Indigo PCI/Cardbus support

* Thu Oct 28 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-19mdk
- add x86_64 rsbac syscalls
- temporarily re-enable IOAPIC workaround on x86_64/VIA
- selected fixes from kernels up to 2.6.10-rc1:
  * try to recover from bugous USB string descriptors (e.g. Freebox USB)
  * fix off-by-one error in TSS limit on x86_64
  * new megaraid v2.20.3.1 driver
  * add Seagate ST3120026AS to SATA SIL mod15 quirks

* Sat Oct 23 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-18mdk
- selected fixes from 2.6.9:
  * fix pointer dereference before NULL check in ACPI thermal driver
  * change TARGET_CPUS on x86_64 to match x86 mach-default
  * fix the Lindenhurst MSI fix on x86-64 to compile again
  * swsuspend fixes to x86_64
  * fix cardbus card memory assignment on x86_64

* Fri Oct 22 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-17mdk
- re-enable KALLSYMS on x86_64
- merge x86_64 cpufreq configs with i386
- 64-bit fixes to acpi/processor module (2.6.9)
- keep acpi/processor module loaded for powernow-k8 (SuSE)

* Mon Oct 11 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-16mdk
- remove devfs automount config
- revert 82801EB ICH5 IDE changes

* Thu Oct  7 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-15mdk
- enable ACPI and Centrino speedstep for Nocona systems
- selected x86-64 fixes from 2.6.9rc3 tree:
  * don't panic when io apic id cannot be set

* Thu Oct  7 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-14mdk
- fix speedtouch support on 64-bit platforms
- selected x86-64 fixes from 2.6.9rc3 tree:
  * add support for NUMA discovery on AMD dual core to x86-64
  * fix sibling map for clustered mode
  * report PNI support in recent AMD CPUs

* Wed Oct  6 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-13mdk
- fix build of ipc32 compat on x86_64
- fix sata_nv on non-CK8-04 systems (Andrew Chew)

* Thu Sep 30 2004 Juan Quintela <quintela@mandrakesoft.com> 2.6.8.1-12mdk
- Fix Oops on sched_api (fix bug #11322)>
- create i686-up-64GB kernel, idea is having PAE kernels for up & smp 
  (only way to have NX protection).


* Mon Sep 27 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-11mdk
- cpufreq update.
- cpuid update.
- tcp_default_win_scale fix. 
- fix rsbac printk.
- ipw2200 0.8.
- msdos/vfat sync.

* Tue Sep  7 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-10mdk
- bootsplash 3.1.6.
- fix bootsplash vt0 display.
- ipw2100 0.54.
- ipw2200 0.7.

* Tue Sep  7 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.8.1-9mdk
- x86_64 2.6.8-1

* Fri Sep  3 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-8mdk
- remember install use ext2.gz initrd image file.
- don't obsoletes kernel-source-2.6.

* Fri Sep  3 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-7mdk
- drop 8139too rx fifo.
- eagle-usb 1.9.9.
- lastest scsi ioctl.

* Fri Sep  3 2004 Juan Quintela <quintela@mandrakesoft.com> 2.6.8.1-6mdk
- fix right Provides/Obsolets for kernel-source*.
- remove dir /usr/src/linux.
- really, really use cramfs for initrd.
- big config clean-up.
- acpi floppy code removal (Oops should have gone).
- orinoco update to 2.4.9-rc1.

* Fri Aug 27 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-5mdk
- drop atkbd interrupt interaction.
- drop nfs, knfsd patch suites.

* Thu Aug 26 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-4mdk
- more info on new kernels :
  o BOOT (i586 up 1GB optimize for size)
  o up (i586 up 4GB + selinux)
  o smp (i686 smp 4GB + selinux)
  o enterprise (i686 smp 64GB + selinux)
  o secure (i686 smp 64GB + selinux + rsbac)
  o i586-up-1GB (legacy kernel + selinux)
- selinux=0 as default.
- rename s/kernel-source/kernel-source-2.6/ provide kernel-source
	 s/kernel-source-stripped/kernel-source-stripped-2.6/ provide kernel-source-2.6 kernel-source
- acpi 20040715.
- ipmi v3.2 af_ipmi, smb.
- really do cramfs as static in kernel.
- cpufreq, software suspend, drm, libata updates
- add agpgart i915 support.
- usb updates.
- don't detect wacom tablet as mouse (flepied).
- lots of mm selected patches like:
  o it8212 support.
  o aio/bio updates.
  o ext2/ext3/jffs fixes.
  o software suspend fixes.
  o selinux fixes.
  o i810 audio fixes.
  o cd/dvd packet writing updates.
  o posix locking fix.
  o cciss/i2o updates.
  o via-rhine fixes.
  o nfsd fixes.

* Thu Aug 26 2004 Juan Quintela <quintela@mandrakesoft.com> 2.6.8.1-3mdk
- used cramfs for initrd instead of ext2.
- weigth reduction program begins.
- 2.6.8.1-q3.
  * unset PCI_NAMES
  * unset IMSTTT
  * unset all elan options (kernel will not work anywhere).
  * unset IKCONFIG (you have the config file in /boot and in all mandrake 
    mirrors).
  * unset EISA.
  * NFS is now a module again (magic in mkinitrd will fix it in next release).
  * now we have:
      - kernel i586 up 1GB (for old machines)
      - kernel up (i686 up 4GB)
      - kernel smp (i686 smp 4GB)
      - kernel p3 smp 64GB
      - kernel secure (i586 smp 4GB)
      - kernel BOOT (i386 up 1GB)
  * plan is remove also BOOT (if weight reduction program has enough success)
    and secure (if options can be integrated without too much fuss in the 
    others).

* Wed Aug 18 2004 Olivier Blin <blino@mandrake.org> 2.6.8.1-2mdk
- update bootsplash patch (from bootsplash.de)

* Mon Aug 16 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8.1-1mdk
- 2.6.8.1.
- alsa 1.0.6.

* Thu Aug 12 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8-0.rc4.1mdk
- rc4 bk3.

* Wed Jul 21 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8-0.rc2.2mdk
- fix double EXTRAVERSION in Makefile (introduce by rsbac patch vs specfile)
- add tc1100-wmi/wacom_acpi driver for HP/Compaq TC1100 tabletpc. (aacton)
- add ntfs support in BOOT kernel.
- next is from mm patchset.
- lastest agpgart.
- cpufreq for nforce2.
- enable suspend/resuming of e1000.
- i810_audio mmio support.
- dvdrw/cdrw packet writing.
- update drivers net pcmcia/wireless.
- posix locking fix.
- x86-64 support singlestep into 32bit syscalls
- 3rdparty BIG update :
  o acx100-0.2.0pre8.
  o eagle-usb-1.9.8.
  o hostap-0.2.4.
  o lirc-20040406.
  o qc-usb-0.6.0.
  o dfg1394-1.3.
  o prism25-0.2.1.
  o ov511-2.28.
  o iscsi-mod-4.0.1.
  o bcm5700-7.1.22.
  o at76c503a-cvs20072004.
  o ndiswrapper-0.8.
  o acecad-3.1.
  o squashfs_2.0.
  o ivtv-cvs21072004.
  o rivatv-0.8.5.
  o sn9c102-1.02_beta. (w9968cf alternative)
  o fuse-1.3.
  o iteraid-092005-09.
  o shfs-0.35.
  o ipw2100-0.50.
  o ipw2200-0.2.

* Sun Jul 18 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8-0.rc2.1mdk
- rc2.
- really enable codepage 437 in BOOT kernel.
- add rsbac security patch in secure kernel.
- modules.description fix (blino).
- no more modversioning module.
- lufs 0.9.7.
- BadRam.

* Fri Jul 16 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8-0.rc1.2mdk
- dazuko 2.0.2.
- codepage 437 module in BOOT kernel.
- kexec is back. 

* Mon Jul 12 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.8-0.rc1.1mdk
- 2.6.8-rc1.
- bootsplash is back.
- ak series amd64 patchsets (gb).
- piix is back as static.
- ide-generic as module.

* Mon Jun 21 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.7-2mdk
- bluetooth mh1.
- mppe mppc 1.0. (florin request)

* Thu Jun 17 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.7-1mdk
- 2.6.7.

* Mon Jun 14 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.7-0.rc3.1mdk
- rc3.
- bk5.
- kdb 4.4 (i386 ia64 x86_64).
- drop bootsplash for the moment.
- disable pata piix driver, enable generic ide, enable PATA ATAPI in libata.

* Wed Jun 02 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.7-0.rc2.1mdk
- rc2.
- bk3.

* Tue May 25 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.7-0.rc1.1mdk
- rc1.
- bootsplash 3.1.5 20040318.
- netfilter (CLASSIFY CONNMARK IPMARK TARPIT addrtype condition connbytes
  h323-conntrack-nat owner-socketlookup pptp-conntrack-nat connlimit
  dstlimit iprange mport nth osf quota random time rtsp-conntrack)

* Wed May 19 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.6-3mdk
- bk6.
- kexec (do reboot,shutdown -r obselete ;)).
- ramdisk BIG fixes.
- quirks disable usb smm bios only on X86 (svetljo).
- drop kdb.

* Fri May 14 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.6-2mdk
- raid locking fix.
- r8169 266-mm2 updates.
- nfs long symlinks fix.
- atkbd_interrupt-interaction.
- input tsdev fixes.
- scancode keycode conversion for 265 fix.
- unplug can sleep.
- sata speedup.
- logitech keyboard fix.
- shm do munmap check.
- set_page_dirty nobuffers race fix.
- revert i8042 interrupt handling.
- fealnx fixes.
- kgdb support.
- acpi procfs fix.
- shfs 0.33.
- isdn devfs support.

* Fri May 10 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.6-1mdk
- 2.6.6.
- DI01 is back, not merged in upstream 
  (ide generic no via8237 sata basic support)

* Fri May  7 2004 Thomas Backlund <tmb@mandrake.org> 2.6.6-0.rc3.1mdk
- 2.6.6-rc3
- rediffed CK01-5
- drop DI01, ZY60 (merged upstream)
- drop MC06 (3rdparty prism54, merged upstream)
- add DV35: add missing errno to tda1004x
- update configs (new stuff in rc3):
  * CONFIG_ATM_FORE200E_USE_TASKLET=y
  * CONFIG_SECURITY_SELINUX_DISABLE=y

* Fri Apr 23 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.6-0.rc2.1mdk
- 2.6.6-rc2.
- lirc devfs remove fix.
- ia64 support.
- eagle-usb 1.9.6.

* Mon Apr 19 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-10mdk
- acpi cardbus pci routing fix.
- yenta irq routing fix for TI chipset.
- oss cmpci driver update to 6.64. 
- BIG isdn update.
- set max symlink to 10.
- gzloop (pixel).
- changeloop (pixel).
- vfat nobadchars option.
- supermount no warning when busy.
- sk98lin buggy vpd workaround. (bad eeprom on ASUS K8V)
- psmouse usb quirks fix (svetljo).
- CAN-2004-0003 r128.
- CAN-2004-0075 vicam.
- CAN-2004-0109 isofs fix.
- CAN-2004-0177 ext3.

* Fri Apr 16 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.3-9mdk
- Merge from AMD64 branch:
  * smaller -BOOT kernel
  * really add /proc/BOOT/{vbe,edid} interfaces
  * update K8 PowerNow!
  * update AMD64 subsystem to selected bits from 2.6.5rc2-1 patchkit
  * workaround VIA IOMMU problems
  * assorted libata fixes (SuSE)
  * enable mga drm & fix 32-bit drm thunks
  * support ITE it8212 RAID chip (Svetljo)
  * update libata core to 2004/03/09 (libata 1.01, sata_promise 0.91)

* Fri Apr 02 2004 Stew Benedict <nplanel@mandrakesoft.com> 2.6.3-8mdk
- CAN-2004-0109 isofs rockridge issue (ZY58)
- CAN-2004-0133 xfs filesystem issue (ZY59)
- CAN-2004-0177 ext3/jbd filesystem issue (ZY60)
- CAN-2004-0178 sb_audio issue (ZY61)
- CAN-2004-0181 jfs filesystem issue (ZY62)

* Wed Mar 17 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-7mdk
- revert xfs updates
- x86_64 really disable IO-APIC on NVIDIA boards (gb)
- usblp updates.
- sys_alarm return value fix.
- edd get legacy parameters.
- fbcon switch fix.
- ide-scsi error handling fixes.
- tun name fix.
- ehci use dma mapping.
- scsi alignment fix.

* Tue Mar  9 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-6mdk
- at76c503a 0.12 Beta8 with MSI6978 Wlan PC2PC support.
- lsb loop test must be work now.
- d_alloc_root, vma corruption, ramdisk memleak fixes.
- ext2/3 no space left fix.
- ICH6 update/fix ID.
- pdc202xx_old updates.
- loop setup race fix.
- pcnet32 transmit hang fix.
- e1000 5.2.30.1-k2.
- AMD 768MPX bootmem fix.
- floppy oops fix.
- i2o bugfixes.
- netfilter ip-route forget proto fix.
- cryptoloop support in BOOT kernel (pixel request).
- from tmb kernel:
  * remove qla2xxx from 3rdparty as it's already in main kernel.org
  * add support for mppe (svtljo)
  * pwc 9.0 Beta1.

* Thu Mar  4 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.6.3-5mdk
- add 32-bit DRM thunks for AMD64 (Egbert Eich).
- update AMD64 bits to 2.6.3-2 patchkit for ia32e support.

* Mon Mar 01 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-4mdk
- netfilter rtsp.
- dcache security fix.
- usb released wait on deregister bus.
- usb-storage update.
- ICH6 piix/libata support.
- aacraid update.
- sk98lin update.
- mtp fusion update to 3.00.03.
- ext3 fix access POSIX compiliant.
- pm runtime deadlock fix.

* Tue Feb 24 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-3mdk
- sg direct io allowed as default.
- bdclaim security oops fix.
- blacklist Compaq ProLiant DL360 (acpi=off).
- ipmi v30 (erwan request).

* Mon Feb 23 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-2mdk
- bootsplash working now.
- bootsplash compil depend fix (chmou).
- no more ide cdrom use ide-scsi.
- fix libata pci quirks (remove 0x24d1).
- parport updates.
- enable ATM in BOOT kernel (tv request).

* Fri Feb 20 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.3-1mdk
- acpi 20040211.
- nforce chipset must be working now.
- lirc create good /dev/lirc/0 now.
- alsa ac97, intel8x0, via82xx updates.
- remove udev requires.

* Thu Feb 12 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-3mdk
- ata_piix doesn't probe 8086:24d1 anymore for the moment.
- remove nforce bad patch.

* Wed Feb 11 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-2mdk
- acpi updates 20040211
- usb updates 20040211
- pnpbios=off as default.
- smb3 uid/gid permisions security fix.
- nforce irq setup fix.
- md update from mm.
- remove airo_mpi and mpi350, merged in airo module kernel.
- parallel port SCSI adapter (ppSCSI) support.
- prism54 20040210.
- hostap 0.1.3.
- at76c503 0.12Beta4.

* Thu Feb 05 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-1mdk
- 2.6.2 enjoy ;)
- qla2xxx updates.
- acx100 0.2.0pre7.
- alsa 1.0.2c.
- bttv, saa7134, cx88 updates.
- logitech wheel mouse must be work now.
- usb, input bk updates.
- alsa usx2y nforce3 pdplus PDAudio echoaudio drivers (tmb).

* Mon Feb 02 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-0.rc3.1mdk
- 2.6.2-rc3
- pnp updates.
- aureal sound cards support. (tmb)
- nForce2 apic fixies. (tmb)
- reeanble lirc. (not lirc_mceusb)

* Fri Jan 30 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-0.rc2.2mdk
- amd64 support (gb)
- new wireless drivers : poldhu, mpi350
- drm updates
- reiserfs in non-debug mode

* Mon Jan 26 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-0.rc2.1mdk
- 2.6.2-rc2.
- acpi 20040116.
- somes mm3 patches.
- alsa 1.0.2 (true verison)
- 80x25 mode selected if vesa mode is bad.
- usb gadget updates from David Brownell.
- dmi updates, pnpbios broken on Intel D865GBF and ASUS A7V8X.
- s/adiusbadsl/eagle-usb/ (new version)
- no module rename (s/[-,]/_/) pixel is a happiest man now ;)
- sync 3rd modules from tmb kernel.

* Wed Jan 21 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.2-0.rc1.1mdk
- 2.6.2. rc1
- agpgart as module now.
- remove drm cvs updates.

* Fri Jan 16 2004 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.1-1mdk
- 2.6.1. bk4
- force inline memcmp when use Os (gb)
- slim BOOT kernel.
- forcedeth v20.
- ndis wrapper 0.4.
- alsa 1.0.1.
- acpi 20031203.
- raid6 20040107.
- drm 20040108.
- nfs/nfsd updates.

* Thu Dec 18 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-1mdk
- 2.6.0 final version ;)
- ndis wrapper 0.3.
- fix uss725.

* Wed Dec 17 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.5mdk
- bk13.
- acecad 1.3.
- uss725.
- bttv videodev i2c videobuf updates 20031216.
- dvb timeout fix.
- mod_marvel (Kevin O'Connor).
- matrox_fb fixes (Kevin O'Connor).
- forcedeth v19.
- kdb build fix.
- add siimage 3114 support.
- prism25 0.2.1-pre16.
- qc-usb cvs20031216.

* Fri Dec 12 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.4mdk
- bk8.
- add vt|ar5k wireless chipset support.
- dos partition table consistency.
- warly touch boot logo ;)
- ndis wrapper 0.2. (only for up kernel)
- alsa 1.0.0rc2.
- agpgart and mousedev as built-in.

* Thu Dec 04 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.3mdk
- bk1:
  * ide-scsi.c uninitialized variable
  * x86 kernel page fault error codes
  * lost wakeups problem
  * missing initialization of /proc/net/tcp seq_file
- rework merge version.h (now all kernel have UTS_RELEASE defined)
- 2.6.0-test11q2 :
  * libata update
  * pwc 8.12
  * prism54 cvs20031203
  * alsa 1.0.0rc1

* Fri Nov 28 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.2mdk
- re-support on the fly module building (great for properitary packages)
- 2.6.0-test11q2 :
  * lots of mm patches
  * import somes 3rdparty and patches : (svetoslav)
    * lirc
    * at76c503a
    * bcm5700
    * dfg1394
    * dxr3
    * iscsi-mod
    * lufs
    * ov511
    * prism25
    * prism54
    * qc-usb

* Mon Nov 24 2003 Nicolas Planel <nplanel@mandrakesoft.com> 2.6.0-0.1mdk
- First version to move on kernel-2.6.0. (aka: ready for a new age).
- 2.6.0-test10q1 :
  * only i386 config for the moment
  * bootsplash 3.1.3
  * mdk logo
  * forcedeth v18
  * adiusbadsl 1.0.4 (untested)
  * acx100 0.2.0pre6
  * hostap 0.1.2

# Local Variables:
# rpm-spec-insert-changelog-version-with-shell: t
# End:
